/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetUsersRequest, GetUsersResponseOK } from "./types/users";
import { CreateUserRequest, CreateUserResponseOK } from "./types/users";
import { GetUserRequest, GetUserResponseOK } from "./types/users";
import { UpdateUserRequest, UpdateUserResponseOK } from "./types/users";
import { DeleteUserRequest, DeleteUserResponseOK } from "./types/users";
import { GetMyUserRequest, GetMyUserResponseOK } from "./types/users";
import { CreateTeamsTeamRequest, CreateTeamsTeamResponseOK } from "./types/teams/team";
import { GetTeamsTeamRequest, GetTeamsTeamResponseOK } from "./types/teams/team";
import { UpdateTeamsTeamRequest, UpdateTeamsTeamResponseOK } from "./types/teams/team";
import { DeleteTeamsTeamRequest, DeleteTeamsTeamResponseOK } from "./types/teams/team";
import { GetTeamsTeamMembersRequest, GetTeamsTeamMembersResponseOK } from "./types/teams/team";
import { AddTeamsTeamMemberRequest, AddTeamsTeamMemberResponseOK } from "./types/teams/team";
import { GetTeamsTeamMemberRequest, GetTeamsTeamMemberResponseOK } from "./types/teams/team";
import { RemoveTeamsTeamMemberRequest, RemoveTeamsTeamMemberResponseOK } from "./types/teams/team";
import { UpdateTeamsTeamMemberRequest, UpdateTeamsTeamMemberResponseOK } from "./types/teams/team";
import { GetMyTeamsRequest, GetMyTeamsResponseOK } from "./types/teams/team";
import { GetUserTeamsRequest, GetUserTeamsResponseOK } from "./types/teams/team";
import { GetUserAssociatedTeamsRequest, GetUserAssociatedTeamsResponseOK } from "./types/teams/team";
import { GetTeamsChannelsRequest, GetTeamsChannelsResponseOK } from "./types/teams/messaging/channel";
import { CreateTeamsChannelRequest, CreateTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChannelRequest, GetTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { UpdateTeamsChannelRequest, UpdateTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { DeleteTeamsChannelRequest, DeleteTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChannelMembersRequest, GetTeamsChannelMembersResponseOK } from "./types/teams/messaging/channel";
import { AddMemberToTeamsChannelRequest, AddMemberToTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { RemoveMemberFromTeamsChannelRequest, RemoveMemberFromTeamsChannelResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChannelMessagesRequest, GetTeamsChannelMessagesResponseOK } from "./types/teams/messaging/channel";
import { SendTeamsChannelMessageRequest, SendTeamsChannelMessageResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChannelMessageRequest, GetTeamsChannelMessageResponseOK } from "./types/teams/messaging/channel";
import { UpdateTeamsChannelMessageRequest, UpdateTeamsChannelMessageResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChannelMessageRepliesRequest, GetTeamsChannelMessageRepliesResponseOK } from "./types/teams/messaging/channel";
import { ReplyToTeamsChannelMessageRequest, ReplyToTeamsChannelMessageResponseOK } from "./types/teams/messaging/channel";
import { GetTeamsChatsRequest, GetTeamsChatsResponseOK } from "./types/teams/messaging/chat";
import { CreateTeamsChatRequest, CreateTeamsChatResponseOK } from "./types/teams/messaging/chat";
import { GetTeamsChatRequest, GetTeamsChatResponseOK } from "./types/teams/messaging/chat";
import { UpdateTeamsChatRequest, UpdateTeamsChatResponseOK } from "./types/teams/messaging/chat";
import { GetTeamsChatMembersRequest, GetTeamsChatMembersResponseOK } from "./types/teams/messaging/chat";
import { AddMemberToTeamsChatRequest, AddMemberToTeamsChatResponseOK } from "./types/teams/messaging/chat";
import { GetTeamsChatMemberRequest, GetTeamsChatMemberResponseOK } from "./types/teams/messaging/chat";
import { RemoveTeamsChatMemberRequest, RemoveTeamsChatMemberResponseOK } from "./types/teams/messaging/chat";
import { GetTeamsChatMessagesRequest, GetTeamsChatMessagesResponseOK } from "./types/teams/messaging/chat";
import { SendTeamsChatMessageRequest, SendTeamsChatMessageResponseOK } from "./types/teams/messaging/chat";
import { GetTeamsChatMessageRequest, GetTeamsChatMessageResponseOK } from "./types/teams/messaging/chat";
import { UpdateTeamsChatMessageRequest, UpdateTeamsChatMessageResponseOK } from "./types/teams/messaging/chat";
import { GetGroupsRequest, GetGroupsResponseOK } from "./types/groups";
import { BaseApiCore, Headers, Response, ErrorStrategyOptionType, PlatformImplementation } from "@managed-api/commons-core";
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from "./errorStrategy";
import { ErrorStrategyBuilder } from "./builders/errorStrategy";
export interface MicrosoftGraphApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class MicrosoftGraphApiCore extends BaseApiCore {
    private options?;
    Users: UsersGroup;
    Teams: TeamsGroup;
    Groups: GroupsGroup;
    All: AllGroup;
    constructor(options?: MicrosoftGraphApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Users;
    private Teams;
    private Groups;
    constructor(Users: UsersGroup, Teams: TeamsGroup, Groups: GroupsGroup);
    /**
     * Get entities from users
     * Alternative usage: Users.getUsers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUsers<T = GetUsersResponseOK>(options?: GetUsersRequest): Promise<GetUsersResponseOK | T>;
    /**
     * Add new entity to users
     * Alternative usage: Users.createUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-post-users?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Get entity from users by key
     * Alternative usage: Users.getUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUser<T = GetUserResponseOK>(options: GetUserRequest): Promise<GetUserResponseOK | T>;
    /**
     * Update entity in users
     * Alternative usage: Users.updateUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateUser<T = UpdateUserResponseOK>(options: UpdateUserRequest): Promise<UpdateUserResponseOK | T>;
    /**
     * Delete entity from users
     * Alternative usage: Users.deleteUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteUser<T = DeleteUserResponseOK>(options: DeleteUserRequest): Promise<DeleteUserResponseOK | T>;
    /**
     * Get me
     * Alternative usage: Users.getMyUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMyUser<T = GetMyUserResponseOK>(options?: GetMyUserRequest): Promise<GetMyUserResponseOK | T>;
    /**
     * Get entity from teams by key
     * Alternative usage: Teams.Team.getTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsTeam<T = GetTeamsTeamResponseOK>(options: GetTeamsTeamRequest): Promise<GetTeamsTeamResponseOK | T>;
    /**
     * Update entity in teams
     * Alternative usage: Teams.Team.updateTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeamsTeam<T = UpdateTeamsTeamResponseOK>(options: UpdateTeamsTeamRequest): Promise<UpdateTeamsTeamResponseOK | T>;
    /**
     * Delete entity from groups
     * Alternative usage: Teams.Team.deleteTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/group-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteTeamsTeam<T = DeleteTeamsTeamResponseOK>(options: DeleteTeamsTeamRequest): Promise<DeleteTeamsTeamResponseOK | T>;
    /**
     * Get entities from related members
     * Alternative usage: Teams.Team.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsTeamMembers<T = GetTeamsTeamMembersResponseOK>(options: GetTeamsTeamMembersRequest): Promise<GetTeamsTeamMembersResponseOK | T>;
    /**
     * Get entity from related members by key
     * Alternative usage: Teams.Team.getMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsTeamMember<T = GetTeamsTeamMemberResponseOK>(options: GetTeamsTeamMemberRequest): Promise<GetTeamsTeamMemberResponseOK | T>;
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Team.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeTeamsTeamMember<T = RemoveTeamsTeamMemberResponseOK>(options: RemoveTeamsTeamMemberRequest): Promise<RemoveTeamsTeamMemberResponseOK | T>;
    /**
     * Get entities from related joinedTeams
     * Alternative usage: Teams.Team.getMyTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMyTeams<T = GetMyTeamsResponseOK>(options?: GetMyTeamsRequest): Promise<GetMyTeamsResponseOK | T>;
    /**
     * Get entities from related joinedTeams
     * Alternative usage: Teams.Team.getUserTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUserTeams<T = GetUserTeamsResponseOK>(options: GetUserTeamsRequest): Promise<GetUserTeamsResponseOK | T>;
    /**
     * Get entities from related associatedTeams
     * Alternative usage: Teams.Team.getUserAssociatedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/associatedteaminfo-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUserAssociatedTeams<T = GetUserAssociatedTeamsResponseOK>(options: GetUserAssociatedTeamsRequest): Promise<GetUserAssociatedTeamsResponseOK | T>;
    /**
     * Get entities from related channels
     * Alternative usage: Teams.Messaging.Channel.getChannels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannels<T = GetTeamsChannelsResponseOK>(options: GetTeamsChannelsRequest): Promise<GetTeamsChannelsResponseOK | T>;
    /**
     * Get entity from related channels by key
     * Alternative usage: Teams.Messaging.Channel.getChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannel<T = GetTeamsChannelResponseOK>(options: GetTeamsChannelRequest): Promise<GetTeamsChannelResponseOK | T>;
    /**
     * Update entity in related channels
     * Alternative usage: Teams.Messaging.Channel.updateChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeamsChannel<T = UpdateTeamsChannelResponseOK>(options: UpdateTeamsChannelRequest): Promise<UpdateTeamsChannelResponseOK | T>;
    /**
     * Delete entity from related channels
     * Alternative usage: Teams.Messaging.Channel.deleteChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteTeamsChannel<T = DeleteTeamsChannelResponseOK>(options: DeleteTeamsChannelRequest): Promise<DeleteTeamsChannelResponseOK | T>;
    /**
     * Get entities from related members
     * Alternative usage: Teams.Messaging.Channel.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannelMembers<T = GetTeamsChannelMembersResponseOK>(options: GetTeamsChannelMembersRequest): Promise<GetTeamsChannelMembersResponseOK | T>;
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Messaging.Channel.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeMemberFromTeamsChannel<T = RemoveMemberFromTeamsChannelResponseOK>(options: RemoveMemberFromTeamsChannelRequest): Promise<RemoveMemberFromTeamsChannelResponseOK | T>;
    /**
     * Get entities from related messages
     * Alternative usage: Teams.Messaging.Channel.getMessages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannelMessages<T = GetTeamsChannelMessagesResponseOK>(options: GetTeamsChannelMessagesRequest): Promise<GetTeamsChannelMessagesResponseOK | T>;
    /**
     * Add new entity to related messages
     * Alternative usage: Teams.Messaging.Channel.sendMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    sendTeamsChannelMessage<T = SendTeamsChannelMessageResponseOK>(options: SendTeamsChannelMessageRequest): Promise<SendTeamsChannelMessageResponseOK | T>;
    /**
     * Get entity from related messages by key
     * Alternative usage: Teams.Messaging.Channel.getMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannelMessage<T = GetTeamsChannelMessageResponseOK>(options: GetTeamsChannelMessageRequest): Promise<GetTeamsChannelMessageResponseOK | T>;
    /**
     * Update entity in related messages
     * Alternative usage: Teams.Messaging.Channel.updateMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeamsChannelMessage<T = UpdateTeamsChannelMessageResponseOK>(options: UpdateTeamsChannelMessageRequest): Promise<UpdateTeamsChannelMessageResponseOK | T>;
    /**
     * Get entities from related replies
     * Alternative usage: Teams.Messaging.Channel.getMessageReplies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-list-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChannelMessageReplies<T = GetTeamsChannelMessageRepliesResponseOK>(options: GetTeamsChannelMessageRepliesRequest): Promise<GetTeamsChannelMessageRepliesResponseOK | T>;
    /**
     * Add new entity to related replies
     * Alternative usage: Teams.Messaging.Channel.replyToMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-post-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    replyToTeamsChannelMessage<T = ReplyToTeamsChannelMessageResponseOK>(options: ReplyToTeamsChannelMessageRequest): Promise<ReplyToTeamsChannelMessageResponseOK | T>;
    /**
     * Get entities from chats
     * Alternative usage: Teams.Messaging.Chat.getChats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChats<T = GetTeamsChatsResponseOK>(options?: GetTeamsChatsRequest): Promise<GetTeamsChatsResponseOK | T>;
    /**
     * Get entity from chats by key
     * Alternative usage: Teams.Messaging.Chat.getChat
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChat<T = GetTeamsChatResponseOK>(options: GetTeamsChatRequest): Promise<GetTeamsChatResponseOK | T>;
    /**
     * Update entity in chats
     * Alternative usage: Teams.Messaging.Chat.updateChat
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeamsChat<T = UpdateTeamsChatResponseOK>(options: UpdateTeamsChatRequest): Promise<UpdateTeamsChatResponseOK | T>;
    /**
     * Get entities from related members
     * Alternative usage: Teams.Messaging.Chat.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChatMembers<T = GetTeamsChatMembersResponseOK>(options: GetTeamsChatMembersRequest): Promise<GetTeamsChatMembersResponseOK | T>;
    /**
     * Get entity from related members by key
     * Alternative usage: Teams.Messaging.Chat.getMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChatMember<T = GetTeamsChatMemberResponseOK>(options: GetTeamsChatMemberRequest): Promise<GetTeamsChatMemberResponseOK | T>;
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Messaging.Chat.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeTeamsChatMember<T = RemoveTeamsChatMemberResponseOK>(options: RemoveTeamsChatMemberRequest): Promise<RemoveTeamsChatMemberResponseOK | T>;
    /**
     * Get entities from related messages
     * Alternative usage: Teams.Messaging.Chat.getMessages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChatMessages<T = GetTeamsChatMessagesResponseOK>(options: GetTeamsChatMessagesRequest): Promise<GetTeamsChatMessagesResponseOK | T>;
    /**
     * Add new entity to related messages
     * Alternative usage: Teams.Messaging.Chat.sendMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    sendTeamsChatMessage<T = SendTeamsChatMessageResponseOK>(options: SendTeamsChatMessageRequest): Promise<SendTeamsChatMessageResponseOK | T>;
    /**
     * Get entity from related messages by key
     * Alternative usage: Teams.Messaging.Chat.getMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeamsChatMessage<T = GetTeamsChatMessageResponseOK>(options: GetTeamsChatMessageRequest): Promise<GetTeamsChatMessageResponseOK | T>;
    /**
     * Update entity in related messages
     * Alternative usage: Teams.Messaging.Chat.updateMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeamsChatMessage<T = UpdateTeamsChatMessageResponseOK>(options: UpdateTeamsChatMessageRequest): Promise<UpdateTeamsChatMessageResponseOK | T>;
    /**
     * Get entities from groups
     * Alternative usage: Groups.getGroups
     * Documentation: https://learn.microsoft.com/en-us/graph/teams-list-all-teams?context=graph%2Fapi%2F1.0&view=graph-rest-1.0
     * @param options Request options.
     */
    getGroups<T = GetGroupsResponseOK>(options?: GetGroupsRequest): Promise<GetGroupsResponseOK | T>;
}
declare class UsersGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get entities from users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUsers<T = GetUsersResponseOK>(options?: GetUsersRequest): Promise<GetUsersResponseOK | T>;
    /**
     * Add new entity to users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-post-users?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Get entity from users by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUser<T = GetUserResponseOK>(options: GetUserRequest): Promise<GetUserResponseOK | T>;
    /**
     * Update entity in users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateUser<T = UpdateUserResponseOK>(options: UpdateUserRequest): Promise<UpdateUserResponseOK | T>;
    /**
     * Delete entity from users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteUser<T = DeleteUserResponseOK>(options: DeleteUserRequest): Promise<DeleteUserResponseOK | T>;
    /**
     * Get me
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMyUser<T = GetMyUserResponseOK>(options?: GetMyUserRequest): Promise<GetMyUserResponseOK | T>;
}
declare class TeamsGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Team: TeamsTeamGroup;
    Messaging: TeamsMessagingGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class TeamsTeamGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Add new entity to teams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    createTeam<T = CreateTeamsTeamResponseOK>(options: CreateTeamsTeamRequest): Promise<CreateTeamsTeamResponseOK | T>;
    /**
     * Get entity from teams by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getTeam<T = GetTeamsTeamResponseOK>(options: GetTeamsTeamRequest): Promise<GetTeamsTeamResponseOK | T>;
    /**
     * Update entity in teams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateTeam<T = UpdateTeamsTeamResponseOK>(options: UpdateTeamsTeamRequest): Promise<UpdateTeamsTeamResponseOK | T>;
    /**
     * Delete entity from groups
     * Documentation: https://learn.microsoft.com/en-us/graph/api/group-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteTeam<T = DeleteTeamsTeamResponseOK>(options: DeleteTeamsTeamRequest): Promise<DeleteTeamsTeamResponseOK | T>;
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMembers<T = GetTeamsTeamMembersResponseOK>(options: GetTeamsTeamMembersRequest): Promise<GetTeamsTeamMembersResponseOK | T>;
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    addMember<T = AddTeamsTeamMemberResponseOK>(options: AddTeamsTeamMemberRequest): Promise<AddTeamsTeamMemberResponseOK | T>;
    /**
     * Get entity from related members by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMember<T = GetTeamsTeamMemberResponseOK>(options: GetTeamsTeamMemberRequest): Promise<GetTeamsTeamMemberResponseOK | T>;
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeMember<T = RemoveTeamsTeamMemberResponseOK>(options: RemoveTeamsTeamMemberRequest): Promise<RemoveTeamsTeamMemberResponseOK | T>;
    /**
     * Update entity in related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateMember<T = UpdateTeamsTeamMemberResponseOK>(options: UpdateTeamsTeamMemberRequest): Promise<UpdateTeamsTeamMemberResponseOK | T>;
    /**
     * Get entities from related joinedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMyTeams<T = GetMyTeamsResponseOK>(options?: GetMyTeamsRequest): Promise<GetMyTeamsResponseOK | T>;
    /**
     * Get entities from related joinedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUserTeams<T = GetUserTeamsResponseOK>(options: GetUserTeamsRequest): Promise<GetUserTeamsResponseOK | T>;
    /**
     * Get entities from related associatedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/associatedteaminfo-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getUserAssociatedTeams<T = GetUserAssociatedTeamsResponseOK>(options: GetUserAssociatedTeamsRequest): Promise<GetUserAssociatedTeamsResponseOK | T>;
}
declare class TeamsMessagingGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Channel: TeamsMessagingChannelGroup;
    Chat: TeamsMessagingChatGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class TeamsMessagingChannelGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get entities from related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getChannels<T = GetTeamsChannelsResponseOK>(options: GetTeamsChannelsRequest): Promise<GetTeamsChannelsResponseOK | T>;
    /**
     * Add new entity to related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    createChannel<T = CreateTeamsChannelResponseOK>(options: CreateTeamsChannelRequest): Promise<CreateTeamsChannelResponseOK | T>;
    /**
     * Get entity from related channels by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getChannel<T = GetTeamsChannelResponseOK>(options: GetTeamsChannelRequest): Promise<GetTeamsChannelResponseOK | T>;
    /**
     * Update entity in related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateChannel<T = UpdateTeamsChannelResponseOK>(options: UpdateTeamsChannelRequest): Promise<UpdateTeamsChannelResponseOK | T>;
    /**
     * Delete entity from related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    deleteChannel<T = DeleteTeamsChannelResponseOK>(options: DeleteTeamsChannelRequest): Promise<DeleteTeamsChannelResponseOK | T>;
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMembers<T = GetTeamsChannelMembersResponseOK>(options: GetTeamsChannelMembersRequest): Promise<GetTeamsChannelMembersResponseOK | T>;
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    addMember<T = AddMemberToTeamsChannelResponseOK>(options: AddMemberToTeamsChannelRequest): Promise<AddMemberToTeamsChannelResponseOK | T>;
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeMember<T = RemoveMemberFromTeamsChannelResponseOK>(options: RemoveMemberFromTeamsChannelRequest): Promise<RemoveMemberFromTeamsChannelResponseOK | T>;
    /**
     * Get entities from related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMessages<T = GetTeamsChannelMessagesResponseOK>(options: GetTeamsChannelMessagesRequest): Promise<GetTeamsChannelMessagesResponseOK | T>;
    /**
     * Add new entity to related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    sendMessage<T = SendTeamsChannelMessageResponseOK>(options: SendTeamsChannelMessageRequest): Promise<SendTeamsChannelMessageResponseOK | T>;
    /**
     * Get entity from related messages by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMessage<T = GetTeamsChannelMessageResponseOK>(options: GetTeamsChannelMessageRequest): Promise<GetTeamsChannelMessageResponseOK | T>;
    /**
     * Update entity in related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateMessage<T = UpdateTeamsChannelMessageResponseOK>(options: UpdateTeamsChannelMessageRequest): Promise<UpdateTeamsChannelMessageResponseOK | T>;
    /**
     * Get entities from related replies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-list-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMessageReplies<T = GetTeamsChannelMessageRepliesResponseOK>(options: GetTeamsChannelMessageRepliesRequest): Promise<GetTeamsChannelMessageRepliesResponseOK | T>;
    /**
     * Add new entity to related replies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-post-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    replyToMessage<T = ReplyToTeamsChannelMessageResponseOK>(options: ReplyToTeamsChannelMessageRequest): Promise<ReplyToTeamsChannelMessageResponseOK | T>;
}
declare class TeamsMessagingChatGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get entities from chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getChats<T = GetTeamsChatsResponseOK>(options?: GetTeamsChatsRequest): Promise<GetTeamsChatsResponseOK | T>;
    /**
     * Add new entity to chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    createChat<T = CreateTeamsChatResponseOK>(options: CreateTeamsChatRequest): Promise<CreateTeamsChatResponseOK | T>;
    /**
     * Get entity from chats by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getChat<T = GetTeamsChatResponseOK>(options: GetTeamsChatRequest): Promise<GetTeamsChatResponseOK | T>;
    /**
     * Update entity in chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateChat<T = UpdateTeamsChatResponseOK>(options: UpdateTeamsChatRequest): Promise<UpdateTeamsChatResponseOK | T>;
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMembers<T = GetTeamsChatMembersResponseOK>(options: GetTeamsChatMembersRequest): Promise<GetTeamsChatMembersResponseOK | T>;
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    addMember<T = AddMemberToTeamsChatResponseOK>(options: AddMemberToTeamsChatRequest): Promise<AddMemberToTeamsChatResponseOK | T>;
    /**
     * Get entity from related members by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMember<T = GetTeamsChatMemberResponseOK>(options: GetTeamsChatMemberRequest): Promise<GetTeamsChatMemberResponseOK | T>;
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    removeMember<T = RemoveTeamsChatMemberResponseOK>(options: RemoveTeamsChatMemberRequest): Promise<RemoveTeamsChatMemberResponseOK | T>;
    /**
     * Get entities from related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMessages<T = GetTeamsChatMessagesResponseOK>(options: GetTeamsChatMessagesRequest): Promise<GetTeamsChatMessagesResponseOK | T>;
    /**
     * Add new entity to related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    sendMessage<T = SendTeamsChatMessageResponseOK>(options: SendTeamsChatMessageRequest): Promise<SendTeamsChatMessageResponseOK | T>;
    /**
     * Get entity from related messages by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    getMessage<T = GetTeamsChatMessageResponseOK>(options: GetTeamsChatMessageRequest): Promise<GetTeamsChatMessageResponseOK | T>;
    /**
     * Update entity in related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    updateMessage<T = UpdateTeamsChatMessageResponseOK>(options: UpdateTeamsChatMessageRequest): Promise<UpdateTeamsChatMessageResponseOK | T>;
}
declare class GroupsGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get entities from groups
     * Documentation: https://learn.microsoft.com/en-us/graph/teams-list-all-teams?context=graph%2Fapi%2F1.0&view=graph-rest-1.0
     * @param options Request options.
     */
    getGroups<T = GetGroupsResponseOK>(options?: GetGroupsRequest): Promise<GetGroupsResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map