/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class MicrosoftGraphApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Users = new UsersGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Teams = new TeamsGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Groups = new GroupsGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Users, this.Teams, this.Groups);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Users, Teams, Groups) {
        this.Users = Users;
        this.Teams = Teams;
        this.Groups = Groups;
    }
    /**
     * Get entities from users
     * Alternative usage: Users.getUsers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUsers(options) {
        return this.Users.getUsers(options);
    }
    /**
     * Add new entity to users
     * Alternative usage: Users.createUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-post-users?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async createUser(options) {
        return this.Users.createUser(options);
    }
    /**
     * Get entity from users by key
     * Alternative usage: Users.getUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUser(options) {
        return this.Users.getUser(options);
    }
    /**
     * Update entity in users
     * Alternative usage: Users.updateUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateUser(options) {
        return this.Users.updateUser(options);
    }
    /**
     * Delete entity from users
     * Alternative usage: Users.deleteUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteUser(options) {
        return this.Users.deleteUser(options);
    }
    /**
     * Get me
     * Alternative usage: Users.getMyUser
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMyUser(options) {
        return this.Users.getMyUser(options);
    }
    /**
     * Get entity from teams by key
     * Alternative usage: Teams.Team.getTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsTeam(options) {
        return this.Teams.Team.getTeam(options);
    }
    /**
     * Update entity in teams
     * Alternative usage: Teams.Team.updateTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeamsTeam(options) {
        return this.Teams.Team.updateTeam(options);
    }
    /**
     * Delete entity from groups
     * Alternative usage: Teams.Team.deleteTeam
     * Documentation: https://learn.microsoft.com/en-us/graph/api/group-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteTeamsTeam(options) {
        return this.Teams.Team.deleteTeam(options);
    }
    /**
     * Get entities from related members
     * Alternative usage: Teams.Team.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsTeamMembers(options) {
        return this.Teams.Team.getMembers(options);
    }
    /**
     * Get entity from related members by key
     * Alternative usage: Teams.Team.getMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsTeamMember(options) {
        return this.Teams.Team.getMember(options);
    }
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Team.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeTeamsTeamMember(options) {
        return this.Teams.Team.removeMember(options);
    }
    /**
     * Get entities from related joinedTeams
     * Alternative usage: Teams.Team.getMyTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMyTeams(options) {
        return this.Teams.Team.getMyTeams(options);
    }
    /**
     * Get entities from related joinedTeams
     * Alternative usage: Teams.Team.getUserTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUserTeams(options) {
        return this.Teams.Team.getUserTeams(options);
    }
    /**
     * Get entities from related associatedTeams
     * Alternative usage: Teams.Team.getUserAssociatedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/associatedteaminfo-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUserAssociatedTeams(options) {
        return this.Teams.Team.getUserAssociatedTeams(options);
    }
    /**
     * Get entities from related channels
     * Alternative usage: Teams.Messaging.Channel.getChannels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannels(options) {
        return this.Teams.Messaging.Channel.getChannels(options);
    }
    /**
     * Get entity from related channels by key
     * Alternative usage: Teams.Messaging.Channel.getChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannel(options) {
        return this.Teams.Messaging.Channel.getChannel(options);
    }
    /**
     * Update entity in related channels
     * Alternative usage: Teams.Messaging.Channel.updateChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeamsChannel(options) {
        return this.Teams.Messaging.Channel.updateChannel(options);
    }
    /**
     * Delete entity from related channels
     * Alternative usage: Teams.Messaging.Channel.deleteChannel
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteTeamsChannel(options) {
        return this.Teams.Messaging.Channel.deleteChannel(options);
    }
    /**
     * Get entities from related members
     * Alternative usage: Teams.Messaging.Channel.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannelMembers(options) {
        return this.Teams.Messaging.Channel.getMembers(options);
    }
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Messaging.Channel.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeMemberFromTeamsChannel(options) {
        return this.Teams.Messaging.Channel.removeMember(options);
    }
    /**
     * Get entities from related messages
     * Alternative usage: Teams.Messaging.Channel.getMessages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannelMessages(options) {
        return this.Teams.Messaging.Channel.getMessages(options);
    }
    /**
     * Add new entity to related messages
     * Alternative usage: Teams.Messaging.Channel.sendMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async sendTeamsChannelMessage(options) {
        return this.Teams.Messaging.Channel.sendMessage(options);
    }
    /**
     * Get entity from related messages by key
     * Alternative usage: Teams.Messaging.Channel.getMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannelMessage(options) {
        return this.Teams.Messaging.Channel.getMessage(options);
    }
    /**
     * Update entity in related messages
     * Alternative usage: Teams.Messaging.Channel.updateMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeamsChannelMessage(options) {
        return this.Teams.Messaging.Channel.updateMessage(options);
    }
    /**
     * Get entities from related replies
     * Alternative usage: Teams.Messaging.Channel.getMessageReplies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-list-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChannelMessageReplies(options) {
        return this.Teams.Messaging.Channel.getMessageReplies(options);
    }
    /**
     * Add new entity to related replies
     * Alternative usage: Teams.Messaging.Channel.replyToMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-post-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async replyToTeamsChannelMessage(options) {
        return this.Teams.Messaging.Channel.replyToMessage(options);
    }
    /**
     * Get entities from chats
     * Alternative usage: Teams.Messaging.Chat.getChats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChats(options) {
        return this.Teams.Messaging.Chat.getChats(options);
    }
    /**
     * Get entity from chats by key
     * Alternative usage: Teams.Messaging.Chat.getChat
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChat(options) {
        return this.Teams.Messaging.Chat.getChat(options);
    }
    /**
     * Update entity in chats
     * Alternative usage: Teams.Messaging.Chat.updateChat
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeamsChat(options) {
        return this.Teams.Messaging.Chat.updateChat(options);
    }
    /**
     * Get entities from related members
     * Alternative usage: Teams.Messaging.Chat.getMembers
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChatMembers(options) {
        return this.Teams.Messaging.Chat.getMembers(options);
    }
    /**
     * Get entity from related members by key
     * Alternative usage: Teams.Messaging.Chat.getMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChatMember(options) {
        return this.Teams.Messaging.Chat.getMember(options);
    }
    /**
     * Delete entity from related members
     * Alternative usage: Teams.Messaging.Chat.removeMember
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeTeamsChatMember(options) {
        return this.Teams.Messaging.Chat.removeMember(options);
    }
    /**
     * Get entities from related messages
     * Alternative usage: Teams.Messaging.Chat.getMessages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChatMessages(options) {
        return this.Teams.Messaging.Chat.getMessages(options);
    }
    /**
     * Add new entity to related messages
     * Alternative usage: Teams.Messaging.Chat.sendMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async sendTeamsChatMessage(options) {
        return this.Teams.Messaging.Chat.sendMessage(options);
    }
    /**
     * Get entity from related messages by key
     * Alternative usage: Teams.Messaging.Chat.getMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeamsChatMessage(options) {
        return this.Teams.Messaging.Chat.getMessage(options);
    }
    /**
     * Update entity in related messages
     * Alternative usage: Teams.Messaging.Chat.updateMessage
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeamsChatMessage(options) {
        return this.Teams.Messaging.Chat.updateMessage(options);
    }
    /**
     * Get entities from groups
     * Alternative usage: Groups.getGroups
     * Documentation: https://learn.microsoft.com/en-us/graph/teams-list-all-teams?context=graph%2Fapi%2F1.0&view=graph-rest-1.0
     * @param options Request options.
     */
    async getGroups(options) {
        return this.Groups.getGroups(options);
    }
}
class UsersGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get entities from users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1.0/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-post-users?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async createUser(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/v1.0/users`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entity from users by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUser(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/users('${encodeURIComponent(id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateUser(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PATCH", `/v1.0/users('${encodeURIComponent(id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Delete entity from users
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteUser(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/v1.0/users('${encodeURIComponent(id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get me
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMyUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1.0/me`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TeamsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Team = new TeamsTeamGroup(implementation, this.getGlobalErrorStrategy);
        this.Messaging = new TeamsMessagingGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class TeamsTeamGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Add new entity to teams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async createTeam(options) {
        var _a, _b;
        const { body, headers, errorStrategy } = options;
        const { template, ...requestBody } = {
            ...body,
            "template@odata.bind": `https://graph.microsoft.com/v1.0/teamsTemplates('${body.template}')`,
            members: (_b = (_a = body) === null || _a === void 0 ? void 0 : _a.members) === null || _b === void 0 ? void 0 : _b.map((member) => {
                var _a;
                const { userType, id, ...cleanedMemberObject } = { ...member, "@odata.type": `#microsoft.graph.${_a = member.userType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${member.id}')` };
                return cleanedMemberObject;
            }),
        };
        const request = new Request("POST", `/v1.0/teams`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entity from teams by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getTeam(options) {
        const { headers, errorStrategy, team_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in teams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateTeam(options) {
        const { body, headers, errorStrategy, team_id } = options;
        const request = new Request("PATCH", `/v1.0/teams('${encodeURIComponent(team_id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Delete entity from groups
     * Documentation: https://learn.microsoft.com/en-us/graph/api/group-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteTeam(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/v1.0/groups('${encodeURIComponent(id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMembers(options) {
        const { headers, errorStrategy, team_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/members`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async addMember(options) {
        var _a;
        const { body, headers, errorStrategy, team_id } = options;
        const { memberType, userId, ...requestBody } = { ...body, "@odata.type": `#microsoft.graph.${_a = body.memberType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${body.userId}')` };
        const request = new Request("POST", `/v1.0/teams('${team_id}')/members`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entity from related members by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMember(options) {
        const { headers, errorStrategy, team_id, membership_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/members('${encodeURIComponent(membership_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeMember(options) {
        const { headers, errorStrategy, team_id, membership_id } = options;
        const request = new Request("DELETE", `/v1.0/teams('${encodeURIComponent(team_id)}')/members('${encodeURIComponent(membership_id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Update entity in related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-update-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateMember(options) {
        var _a;
        const { body, headers, errorStrategy, team_id, member_id } = options;
        const { memberType, ...requestBody } = { ...body, "@odata.type": `#microsoft.graph.${_a = body.memberType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}` };
        const request = new Request("PATCH", `/v1.0/teams('${team_id}')/members('${member_id}')`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entities from related joinedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMyTeams(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1.0/me/joinedTeams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entities from related joinedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/user-list-joinedteams?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUserTeams(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/users('${encodeURIComponent(id)}')/joinedTeams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entities from related associatedTeams
     * Documentation: https://learn.microsoft.com/en-us/graph/api/associatedteaminfo-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getUserAssociatedTeams(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/users('${encodeURIComponent(id)}')/teamwork/associatedTeams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TeamsMessagingGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Channel = new TeamsMessagingChannelGroup(implementation, this.getGlobalErrorStrategy);
        this.Chat = new TeamsMessagingChatGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class TeamsMessagingChannelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get entities from related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getChannels(options) {
        const { headers, errorStrategy, team_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async createChannel(options) {
        var _a;
        const { body, headers, errorStrategy, team_id } = options;
        const requestBody = {
            ...body,
            members: (_a = body.members) === null || _a === void 0 ? void 0 : _a.map((member) => {
                var _a;
                const { userType, id, ...cleanedMemberObject } = { ...member, "@odata.type": `#microsoft.graph.${_a = member.userType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${member.id}')` };
                return cleanedMemberObject;
            }),
        };
        const request = new Request("POST", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entity from related channels by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getChannel(options) {
        const { headers, errorStrategy, team_id, channel_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateChannel(options) {
        const { body, headers, errorStrategy, team_id, channel_id } = options;
        const request = new Request("PATCH", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Delete entity from related channels
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async deleteChannel(options) {
        const { headers, errorStrategy, team_id, channel_id } = options;
        const request = new Request("DELETE", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMembers(options) {
        const { headers, errorStrategy, team_id, channel_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/members`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async addMember(options) {
        var _a;
        const { body, headers, errorStrategy, team_id, channel_id } = options;
        const { memberType, userId, ...requestBody } = { ...body, "@odata.type": `#microsoft.graph.${_a = body.memberType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${body.userId}')` };
        const request = new Request("POST", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/members/`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeMember(options) {
        const { headers, errorStrategy, team_id, channel_id, membership_id } = options;
        const request = new Request("DELETE", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/members('${encodeURIComponent(membership_id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entities from related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMessages(options) {
        const { headers, errorStrategy, team_id, channel_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/channel-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async sendMessage(options) {
        const { body, headers, errorStrategy, team_id, channel_id } = options;
        const request = new Request("POST", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entity from related messages by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMessage(options) {
        const { headers, errorStrategy, team_id, channel_id, message_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages('${encodeURIComponent(message_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateMessage(options) {
        const { body, headers, errorStrategy, team_id, channel_id, message_id } = options;
        const request = new Request("PATCH", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages('${encodeURIComponent(message_id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entities from related replies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-list-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMessageReplies(options) {
        const { headers, errorStrategy, team_id, channel_id, message_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages('${encodeURIComponent(message_id)}')/replies`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related replies
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-post-replies?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async replyToMessage(options) {
        const { body, headers, errorStrategy, team_id, channel_id, message_id } = options;
        const request = new Request("POST", `/v1.0/teams('${encodeURIComponent(team_id)}')/channels('${encodeURIComponent(channel_id)}')/messages('${encodeURIComponent(message_id)}')/replies`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TeamsMessagingChatGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get entities from chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getChats(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1.0/chats`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async createChat(options) {
        const { body, headers, errorStrategy } = options;
        const requestBody = {
            ...body,
            members: body.members.map((member) => {
                var _a;
                const { userType, id, ...cleanedMemberObject } = { ...member, "@odata.type": `#microsoft.graph.${_a = member.userType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${member.id}')` };
                return cleanedMemberObject;
            }),
        };
        const request = new Request("POST", `/v1.0/chats`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entity from chats by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getChat(options) {
        const { headers, errorStrategy, chat_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/chats('${encodeURIComponent(chat_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in chats
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-patch?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateChat(options) {
        const { body, headers, errorStrategy, chat_id } = options;
        const request = new Request("PATCH", `/v1.0/chats('${encodeURIComponent(chat_id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entities from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMembers(options) {
        const { headers, errorStrategy, chat_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/chats('${encodeURIComponent(chat_id)}')/members`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/team-post-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async addMember(options) {
        var _a;
        const { body, headers, errorStrategy, chat_id } = options;
        const { memberType, userId, ...requestBody } = { ...body, "@odata.type": `#microsoft.graph.${_a = body.memberType, (_a !== null && _a !== void 0 ? _a : "aadUserConversationMember")}`, "user@odata.bind": `https://graph.microsoft.com/v1.0/users('${body.userId}')` };
        const request = new Request("POST", `/v1.0/chats('${encodeURIComponent(chat_id)}')/members/`, constructHeaders(requestBody, headers), JSON.stringify(requestBody));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entity from related members by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-get-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMember(options) {
        const { headers, errorStrategy, chat_id, membership_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/chats('${encodeURIComponent(chat_id)}')/members('${encodeURIComponent(membership_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete entity from related members
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-delete-members?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async removeMember(options) {
        const { headers, errorStrategy, chat_id, membership_id } = options;
        const request = new Request("DELETE", `/v1.0/chats('${encodeURIComponent(chat_id)}')/members('${encodeURIComponent(membership_id)}')`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get entities from related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-list-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMessages(options) {
        const { headers, errorStrategy, chat_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/chats('${encodeURIComponent(chat_id)}')/messages`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add new entity to related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chat-post-messages?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async sendMessage(options) {
        const { body, headers, errorStrategy, chat_id } = options;
        const request = new Request("POST", `/v1.0/chats('${encodeURIComponent(chat_id)}')/messages`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get entity from related messages by key
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-get?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async getMessage(options) {
        const { headers, errorStrategy, chat_id, message_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1.0/chats('${encodeURIComponent(chat_id)}')/messages('${encodeURIComponent(message_id)}')`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update entity in related messages
     * Documentation: https://learn.microsoft.com/en-us/graph/api/chatmessage-update?view=graph-rest-1.0&tabs=http
     * @param options Request options.
     */
    async updateMessage(options) {
        const { body, headers, errorStrategy, chat_id, message_id } = options;
        const request = new Request("PATCH", `/v1.0/chats('${encodeURIComponent(chat_id)}')/messages('${encodeURIComponent(message_id)}')`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class GroupsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get entities from groups
     * Documentation: https://learn.microsoft.com/en-us/graph/teams-list-all-teams?context=graph%2Fapi%2F1.0&view=graph-rest-1.0
     * @param options Request options.
     */
    async getGroups(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/v1.0/groups`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map