/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CountAsResponse } from "../definitions/CountAsResponse";
import { MicrosoftGraphGroupAsResponse } from "../definitions/MicrosoftGraphGroupAsResponse";
import { ErrorAsResponse } from "../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "deletedDateTime" | "deletedDateTime desc" | "assignedLabels/displayName" | "assignedLabels/displayName desc" | "assignedLabels/labelId" | "assignedLabels/labelId desc" | "assignedLicenses/disabledPlans" | "assignedLicenses/disabledPlans desc" | "assignedLicenses/skuId" | "assignedLicenses/skuId desc" | "classification" | "classification desc" | "createdDateTime" | "createdDateTime desc" | "description" | "description desc" | "displayName" | "displayName desc" | "expirationDateTime" | "expirationDateTime desc" | "groupTypes" | "groupTypes desc" | "hasMembersWithLicenseErrors" | "hasMembersWithLicenseErrors desc" | "isAssignableToRole" | "isAssignableToRole desc" | "licenseProcessingState/state" | "licenseProcessingState/state desc" | "mail" | "mail desc" | "mailEnabled" | "mailEnabled desc" | "mailNickname" | "mailNickname desc" | "membershipRule" | "membershipRule desc" | "membershipRuleProcessingState" | "membershipRuleProcessingState desc" | "onPremisesDomainName" | "onPremisesDomainName desc" | "onPremisesLastSyncDateTime" | "onPremisesLastSyncDateTime desc" | "onPremisesNetBiosName" | "onPremisesNetBiosName desc" | "onPremisesProvisioningErrors/category" | "onPremisesProvisioningErrors/category desc" | "onPremisesProvisioningErrors/occurredDateTime" | "onPremisesProvisioningErrors/occurredDateTime desc" | "onPremisesProvisioningErrors/propertyCausingError" | "onPremisesProvisioningErrors/propertyCausingError desc" | "onPremisesProvisioningErrors/value" | "onPremisesProvisioningErrors/value desc" | "onPremisesSamAccountName" | "onPremisesSamAccountName desc" | "onPremisesSecurityIdentifier" | "onPremisesSecurityIdentifier desc" | "onPremisesSyncEnabled" | "onPremisesSyncEnabled desc" | "preferredDataLocation" | "preferredDataLocation desc" | "preferredLanguage" | "preferredLanguage desc" | "proxyAddresses" | "proxyAddresses desc" | "renewedDateTime" | "renewedDateTime desc" | "securityEnabled" | "securityEnabled desc" | "securityIdentifier" | "securityIdentifier desc" | "theme" | "theme desc" | "visibility" | "visibility desc" | "allowExternalSenders" | "allowExternalSenders desc" | "autoSubscribeNewMembers" | "autoSubscribeNewMembers desc" | "hideFromAddressLists" | "hideFromAddressLists desc" | "hideFromOutlookClients" | "hideFromOutlookClients desc" | "isSubscribedByMail" | "isSubscribedByMail desc" | "unseenCount" | "unseenCount desc" | "isArchived" | "isArchived desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "deletedDateTime" | "assignedLabels" | "assignedLicenses" | "classification" | "createdDateTime" | "description" | "displayName" | "expirationDateTime" | "groupTypes" | "hasMembersWithLicenseErrors" | "isAssignableToRole" | "licenseProcessingState" | "mail" | "mailEnabled" | "mailNickname" | "membershipRule" | "membershipRuleProcessingState" | "onPremisesDomainName" | "onPremisesLastSyncDateTime" | "onPremisesNetBiosName" | "onPremisesProvisioningErrors" | "onPremisesSamAccountName" | "onPremisesSecurityIdentifier" | "onPremisesSyncEnabled" | "preferredDataLocation" | "preferredLanguage" | "proxyAddresses" | "renewedDateTime" | "securityEnabled" | "securityIdentifier" | "theme" | "visibility" | "allowExternalSenders" | "autoSubscribeNewMembers" | "hideFromAddressLists" | "hideFromOutlookClients" | "isSubscribedByMail" | "unseenCount" | "isArchived">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "appRoleAssignments" | "createdOnBehalfOf" | "memberOf" | "members" | "membersWithLicenseErrors" | "owners" | "permissionGrants" | "settings" | "transitiveMemberOf" | "transitiveMembers" | "acceptedSenders" | "calendar" | "calendarView" | "conversations" | "events" | "rejectedSenders" | "threads" | "drive" | "drives" | "sites" | "extensions" | "groupLifecyclePolicies" | "planner" | "onenote" | "photo" | "photos" | "team">;
}
declare type GetGroupsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphGroupAsResponse>;
};
export interface GetGroupsResponseOK extends GetGroupsResponseOKType {
}
declare type GetGroupsResponseErrorType = ErrorAsResponse;
export interface GetGroupsResponseError extends GetGroupsResponseErrorType {
}
export {};
//# sourceMappingURL=groups.d.ts.map