/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CountAsResponse } from "../../../definitions/CountAsResponse";
import { MicrosoftGraphChannelAsResponse } from "../../../definitions/MicrosoftGraphChannelAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { MicrosoftGraphChannelCreate } from "../../../definitions/MicrosoftGraphChannelCreate";
import { MicrosoftGraphChannelUpdate } from "../../../definitions/MicrosoftGraphChannelUpdate";
import { MicrosoftGraphConversationMemberAsResponse } from "../../../definitions/MicrosoftGraphConversationMemberAsResponse";
import { MicrosoftGraphChatMessageAsResponse } from "../../../definitions/MicrosoftGraphChatMessageAsResponse";
import { MicrosoftGraphChatMessageCreate } from "../../../definitions/MicrosoftGraphChatMessageCreate";
import { MicrosoftGraphChatMessageUpdate } from "../../../definitions/MicrosoftGraphChatMessageUpdate";
export interface GetTeamsChannelsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "createdDateTime" | "createdDateTime desc" | "description" | "description desc" | "displayName" | "displayName desc" | "email" | "email desc" | "isFavoriteByDefault" | "isFavoriteByDefault desc" | "membershipType" | "membershipType desc" | "tenantId" | "tenantId desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "createdDateTime" | "description" | "displayName" | "email" | "isFavoriteByDefault" | "membershipType" | "tenantId" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "filesFolder" | "members" | "messages" | "sharedWithTeams" | "tabs">;
}
declare type GetTeamsChannelsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphChannelAsResponse>;
};
export interface GetTeamsChannelsResponseOK extends GetTeamsChannelsResponseOKType {
}
declare type GetTeamsChannelsResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelsResponseError extends GetTeamsChannelsResponseErrorType {
}
export interface CreateTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    body: MicrosoftGraphChannelCreate;
}
declare type CreateTeamsChannelResponseOKType = MicrosoftGraphChannelAsResponse;
export interface CreateTeamsChannelResponseOK extends CreateTeamsChannelResponseOKType {
}
declare type CreateTeamsChannelResponseErrorType = ErrorAsResponse;
export interface CreateTeamsChannelResponseError extends CreateTeamsChannelResponseErrorType {
}
export interface GetTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "createdDateTime" | "description" | "displayName" | "email" | "isFavoriteByDefault" | "membershipType" | "tenantId" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "filesFolder" | "members" | "messages" | "sharedWithTeams" | "tabs">;
}
declare type GetTeamsChannelResponseOKType = MicrosoftGraphChannelAsResponse;
export interface GetTeamsChannelResponseOK extends GetTeamsChannelResponseOKType {
}
declare type GetTeamsChannelResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelResponseError extends GetTeamsChannelResponseErrorType {
}
export interface UpdateTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    body: MicrosoftGraphChannelUpdate;
}
export declare type UpdateTeamsChannelResponseOK = undefined;
declare type UpdateTeamsChannelResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsChannelResponseError extends UpdateTeamsChannelResponseErrorType {
}
export interface DeleteTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
}
export declare type DeleteTeamsChannelResponseOK = undefined;
declare type DeleteTeamsChannelResponseErrorType = ErrorAsResponse;
export interface DeleteTeamsChannelResponseError extends DeleteTeamsChannelResponseErrorType {
}
export interface GetTeamsChannelMembersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "displayName" | "displayName desc" | "roles" | "roles desc" | "visibleHistoryStartDateTime" | "visibleHistoryStartDateTime desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "roles" | "visibleHistoryStartDateTime">;
}
declare type GetTeamsChannelMembersResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphConversationMemberAsResponse>;
};
export interface GetTeamsChannelMembersResponseOK extends GetTeamsChannelMembersResponseOKType {
}
declare type GetTeamsChannelMembersResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelMembersResponseError extends GetTeamsChannelMembersResponseErrorType {
}
export interface AddMemberToTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    team_id: string;
    channel_id: string;
    body: {
        userId: string;
        memberType?: string;
        roles?: Array<"owner" | "guest">;
        [x: string]: any;
    };
}
declare type AddMemberToTeamsChannelResponseOKType = MicrosoftGraphConversationMemberAsResponse;
export interface AddMemberToTeamsChannelResponseOK extends AddMemberToTeamsChannelResponseOKType {
}
declare type AddMemberToTeamsChannelResponseErrorType = ErrorAsResponse;
export interface AddMemberToTeamsChannelResponseError extends AddMemberToTeamsChannelResponseErrorType {
}
export interface RemoveMemberFromTeamsChannelRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * key: id
     */
    membership_id: string;
}
export declare type RemoveMemberFromTeamsChannelResponseOK = undefined;
declare type RemoveMemberFromTeamsChannelResponseErrorType = ErrorAsResponse;
export interface RemoveMemberFromTeamsChannelResponseError extends RemoveMemberFromTeamsChannelResponseErrorType {
}
export interface GetTeamsChannelMessagesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "attachments/content" | "attachments/content desc" | "attachments/contentType" | "attachments/contentType desc" | "attachments/contentUrl" | "attachments/contentUrl desc" | "attachments/id" | "attachments/id desc" | "attachments/name" | "attachments/name desc" | "attachments/thumbnailUrl" | "attachments/thumbnailUrl desc" | "body/content" | "body/content desc" | "body/contentType" | "body/contentType desc" | "channelIdentity/channelId" | "channelIdentity/channelId desc" | "channelIdentity/teamId" | "channelIdentity/teamId desc" | "chatId" | "chatId desc" | "createdDateTime" | "createdDateTime desc" | "deletedDateTime" | "deletedDateTime desc" | "etag" | "etag desc" | "from/application/displayName" | "from/application/displayName desc" | "from/application/id" | "from/application/id desc" | "from/device/displayName" | "from/device/displayName desc" | "from/device/id" | "from/device/id desc" | "from/user/displayName" | "from/user/displayName desc" | "from/user/id" | "from/user/id desc" | "importance" | "importance desc" | "lastEditedDateTime" | "lastEditedDateTime desc" | "lastModifiedDateTime" | "lastModifiedDateTime desc" | "locale" | "locale desc" | "mentions/id" | "mentions/id desc" | "mentions/mentioned/application/displayName" | "mentions/mentioned/application/displayName desc" | "mentions/mentioned/application/id" | "mentions/mentioned/application/id desc" | "mentions/mentioned/device/displayName" | "mentions/mentioned/device/displayName desc" | "mentions/mentioned/device/id" | "mentions/mentioned/device/id desc" | "mentions/mentioned/user/displayName" | "mentions/mentioned/user/displayName desc" | "mentions/mentioned/user/id" | "mentions/mentioned/user/id desc" | "mentions/mentioned/conversation/displayName" | "mentions/mentioned/conversation/displayName desc" | "mentions/mentioned/conversation/id" | "mentions/mentioned/conversation/id desc" | "mentions/mentioned/conversation/conversationIdentityType" | "mentions/mentioned/conversation/conversationIdentityType desc" | "mentions/mentionText" | "mentions/mentionText desc" | "messageType" | "messageType desc" | "policyViolation/dlpAction" | "policyViolation/dlpAction desc" | "policyViolation/justificationText" | "policyViolation/justificationText desc" | "policyViolation/policyTip/complianceUrl" | "policyViolation/policyTip/complianceUrl desc" | "policyViolation/policyTip/generalText" | "policyViolation/policyTip/generalText desc" | "policyViolation/policyTip/matchedConditionDescriptions" | "policyViolation/policyTip/matchedConditionDescriptions desc" | "policyViolation/userAction" | "policyViolation/userAction desc" | "policyViolation/verdictDetails" | "policyViolation/verdictDetails desc" | "reactions/createdDateTime" | "reactions/createdDateTime desc" | "reactions/reactionType" | "reactions/reactionType desc" | "reactions/user/application/displayName" | "reactions/user/application/displayName desc" | "reactions/user/application/id" | "reactions/user/application/id desc" | "reactions/user/device/displayName" | "reactions/user/device/displayName desc" | "reactions/user/device/id" | "reactions/user/device/id desc" | "reactions/user/user/displayName" | "reactions/user/user/displayName desc" | "reactions/user/user/id" | "reactions/user/user/id desc" | "replyToId" | "replyToId desc" | "subject" | "subject desc" | "summary" | "summary desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "attachments" | "body" | "channelIdentity" | "chatId" | "createdDateTime" | "deletedDateTime" | "etag" | "eventDetail" | "from" | "importance" | "lastEditedDateTime" | "lastModifiedDateTime" | "locale" | "mentions" | "messageType" | "policyViolation" | "reactions" | "replyToId" | "subject" | "summary" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "hostedContents" | "replies">;
}
declare type GetTeamsChannelMessagesResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphChatMessageAsResponse>;
    "@odata.deltaLink"?: string;
};
export interface GetTeamsChannelMessagesResponseOK extends GetTeamsChannelMessagesResponseOKType {
}
declare type GetTeamsChannelMessagesResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelMessagesResponseError extends GetTeamsChannelMessagesResponseErrorType {
}
export interface SendTeamsChannelMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    body: MicrosoftGraphChatMessageCreate;
}
declare type SendTeamsChannelMessageResponseOKType = MicrosoftGraphChatMessageAsResponse;
export interface SendTeamsChannelMessageResponseOK extends SendTeamsChannelMessageResponseOKType {
}
declare type SendTeamsChannelMessageResponseErrorType = ErrorAsResponse;
export interface SendTeamsChannelMessageResponseError extends SendTeamsChannelMessageResponseErrorType {
}
export interface GetTeamsChannelMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * key: id
     */
    message_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "attachments" | "body" | "channelIdentity" | "chatId" | "createdDateTime" | "deletedDateTime" | "etag" | "eventDetail" | "from" | "importance" | "lastEditedDateTime" | "lastModifiedDateTime" | "locale" | "mentions" | "messageType" | "policyViolation" | "reactions" | "replyToId" | "subject" | "summary" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "hostedContents" | "replies">;
}
declare type GetTeamsChannelMessageResponseOKType = MicrosoftGraphChatMessageAsResponse;
export interface GetTeamsChannelMessageResponseOK extends GetTeamsChannelMessageResponseOKType {
}
declare type GetTeamsChannelMessageResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelMessageResponseError extends GetTeamsChannelMessageResponseErrorType {
}
export interface UpdateTeamsChannelMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * key: id
     */
    message_id: string;
    body: MicrosoftGraphChatMessageUpdate;
}
export declare type UpdateTeamsChannelMessageResponseOK = undefined;
declare type UpdateTeamsChannelMessageResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsChannelMessageResponseError extends UpdateTeamsChannelMessageResponseErrorType {
}
export interface GetTeamsChannelMessageRepliesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * key: id
     */
    message_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "attachments/content" | "attachments/content desc" | "attachments/contentType" | "attachments/contentType desc" | "attachments/contentUrl" | "attachments/contentUrl desc" | "attachments/id" | "attachments/id desc" | "attachments/name" | "attachments/name desc" | "attachments/thumbnailUrl" | "attachments/thumbnailUrl desc" | "body/content" | "body/content desc" | "body/contentType" | "body/contentType desc" | "channelIdentity/channelId" | "channelIdentity/channelId desc" | "channelIdentity/teamId" | "channelIdentity/teamId desc" | "chatId" | "chatId desc" | "createdDateTime" | "createdDateTime desc" | "deletedDateTime" | "deletedDateTime desc" | "etag" | "etag desc" | "from/application/displayName" | "from/application/displayName desc" | "from/application/id" | "from/application/id desc" | "from/device/displayName" | "from/device/displayName desc" | "from/device/id" | "from/device/id desc" | "from/user/displayName" | "from/user/displayName desc" | "from/user/id" | "from/user/id desc" | "importance" | "importance desc" | "lastEditedDateTime" | "lastEditedDateTime desc" | "lastModifiedDateTime" | "lastModifiedDateTime desc" | "locale" | "locale desc" | "mentions/id" | "mentions/id desc" | "mentions/mentioned/application/displayName" | "mentions/mentioned/application/displayName desc" | "mentions/mentioned/application/id" | "mentions/mentioned/application/id desc" | "mentions/mentioned/device/displayName" | "mentions/mentioned/device/displayName desc" | "mentions/mentioned/device/id" | "mentions/mentioned/device/id desc" | "mentions/mentioned/user/displayName" | "mentions/mentioned/user/displayName desc" | "mentions/mentioned/user/id" | "mentions/mentioned/user/id desc" | "mentions/mentioned/conversation/displayName" | "mentions/mentioned/conversation/displayName desc" | "mentions/mentioned/conversation/id" | "mentions/mentioned/conversation/id desc" | "mentions/mentioned/conversation/conversationIdentityType" | "mentions/mentioned/conversation/conversationIdentityType desc" | "mentions/mentionText" | "mentions/mentionText desc" | "messageType" | "messageType desc" | "policyViolation/dlpAction" | "policyViolation/dlpAction desc" | "policyViolation/justificationText" | "policyViolation/justificationText desc" | "policyViolation/policyTip/complianceUrl" | "policyViolation/policyTip/complianceUrl desc" | "policyViolation/policyTip/generalText" | "policyViolation/policyTip/generalText desc" | "policyViolation/policyTip/matchedConditionDescriptions" | "policyViolation/policyTip/matchedConditionDescriptions desc" | "policyViolation/userAction" | "policyViolation/userAction desc" | "policyViolation/verdictDetails" | "policyViolation/verdictDetails desc" | "reactions/createdDateTime" | "reactions/createdDateTime desc" | "reactions/reactionType" | "reactions/reactionType desc" | "reactions/user/application/displayName" | "reactions/user/application/displayName desc" | "reactions/user/application/id" | "reactions/user/application/id desc" | "reactions/user/device/displayName" | "reactions/user/device/displayName desc" | "reactions/user/device/id" | "reactions/user/device/id desc" | "reactions/user/user/displayName" | "reactions/user/user/displayName desc" | "reactions/user/user/id" | "reactions/user/user/id desc" | "replyToId" | "replyToId desc" | "subject" | "subject desc" | "summary" | "summary desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "attachments" | "body" | "channelIdentity" | "chatId" | "createdDateTime" | "deletedDateTime" | "etag" | "eventDetail" | "from" | "importance" | "lastEditedDateTime" | "lastModifiedDateTime" | "locale" | "mentions" | "messageType" | "policyViolation" | "reactions" | "replyToId" | "subject" | "summary" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "hostedContents" | "replies">;
}
declare type GetTeamsChannelMessageRepliesResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphChatMessageAsResponse>;
};
export interface GetTeamsChannelMessageRepliesResponseOK extends GetTeamsChannelMessageRepliesResponseOKType {
}
declare type GetTeamsChannelMessageRepliesResponseErrorType = ErrorAsResponse;
export interface GetTeamsChannelMessageRepliesResponseError extends GetTeamsChannelMessageRepliesResponseErrorType {
}
export interface ReplyToTeamsChannelMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    channel_id: string;
    /**
     * key: id
     */
    message_id: string;
    body: MicrosoftGraphChatMessageCreate;
}
declare type ReplyToTeamsChannelMessageResponseOKType = MicrosoftGraphChatMessageAsResponse;
export interface ReplyToTeamsChannelMessageResponseOK extends ReplyToTeamsChannelMessageResponseOKType {
}
declare type ReplyToTeamsChannelMessageResponseErrorType = ErrorAsResponse;
export interface ReplyToTeamsChannelMessageResponseError extends ReplyToTeamsChannelMessageResponseErrorType {
}
export {};
//# sourceMappingURL=channel.d.ts.map