/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CountAsResponse } from "../../../definitions/CountAsResponse";
import { MicrosoftGraphChatAsResponse } from "../../../definitions/MicrosoftGraphChatAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { MicrosoftGraphChatCreate } from "../../../definitions/MicrosoftGraphChatCreate";
import { MicrosoftGraphChatUpdate } from "../../../definitions/MicrosoftGraphChatUpdate";
import { MicrosoftGraphConversationMemberAsResponse } from "../../../definitions/MicrosoftGraphConversationMemberAsResponse";
import { MicrosoftGraphChatMessageAsResponse } from "../../../definitions/MicrosoftGraphChatMessageAsResponse";
import { MicrosoftGraphChatMessageCreate } from "../../../definitions/MicrosoftGraphChatMessageCreate";
import { MicrosoftGraphChatMessageUpdate } from "../../../definitions/MicrosoftGraphChatMessageUpdate";
export interface GetTeamsChatsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "chatType" | "chatType desc" | "createdDateTime" | "createdDateTime desc" | "lastUpdatedDateTime" | "lastUpdatedDateTime desc" | "onlineMeetingInfo/calendarEventId" | "onlineMeetingInfo/calendarEventId desc" | "onlineMeetingInfo/joinWebUrl" | "onlineMeetingInfo/joinWebUrl desc" | "onlineMeetingInfo/organizer/displayName" | "onlineMeetingInfo/organizer/displayName desc" | "onlineMeetingInfo/organizer/id" | "onlineMeetingInfo/organizer/id desc" | "onlineMeetingInfo/organizer/userIdentityType" | "onlineMeetingInfo/organizer/userIdentityType desc" | "tenantId" | "tenantId desc" | "topic" | "topic desc" | "viewpoint/isHidden" | "viewpoint/isHidden desc" | "viewpoint/lastMessageReadDateTime" | "viewpoint/lastMessageReadDateTime desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "chatType" | "createdDateTime" | "lastUpdatedDateTime" | "onlineMeetingInfo" | "tenantId" | "topic" | "viewpoint" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "installedApps" | "lastMessagePreview" | "members" | "messages" | "pinnedMessages" | "tabs">;
}
declare type GetTeamsChatsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphChatAsResponse>;
};
export interface GetTeamsChatsResponseOK extends GetTeamsChatsResponseOKType {
}
declare type GetTeamsChatsResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatsResponseError extends GetTeamsChatsResponseErrorType {
}
export interface CreateTeamsChatRequest extends HeadersOption, ErrorStrategyOption {
    body: MicrosoftGraphChatCreate;
}
declare type CreateTeamsChatResponseOKType = MicrosoftGraphChatAsResponse;
export interface CreateTeamsChatResponseOK extends CreateTeamsChatResponseOKType {
}
declare type CreateTeamsChatResponseErrorType = ErrorAsResponse;
export interface CreateTeamsChatResponseError extends CreateTeamsChatResponseErrorType {
}
export interface GetTeamsChatRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "chatType" | "createdDateTime" | "lastUpdatedDateTime" | "onlineMeetingInfo" | "tenantId" | "topic" | "viewpoint" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "installedApps" | "lastMessagePreview" | "members" | "messages" | "pinnedMessages" | "tabs">;
}
declare type GetTeamsChatResponseOKType = MicrosoftGraphChatAsResponse;
export interface GetTeamsChatResponseOK extends GetTeamsChatResponseOKType {
}
declare type GetTeamsChatResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatResponseError extends GetTeamsChatResponseErrorType {
}
export interface UpdateTeamsChatRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    body: MicrosoftGraphChatUpdate;
}
export declare type UpdateTeamsChatResponseOK = undefined;
declare type UpdateTeamsChatResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsChatResponseError extends UpdateTeamsChatResponseErrorType {
}
export interface GetTeamsChatMembersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "displayName" | "displayName desc" | "roles" | "roles desc" | "visibleHistoryStartDateTime" | "visibleHistoryStartDateTime desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "roles" | "visibleHistoryStartDateTime">;
}
declare type GetTeamsChatMembersResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphConversationMemberAsResponse>;
};
export interface GetTeamsChatMembersResponseOK extends GetTeamsChatMembersResponseOKType {
}
declare type GetTeamsChatMembersResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatMembersResponseError extends GetTeamsChatMembersResponseErrorType {
}
export interface AddMemberToTeamsChatRequest extends HeadersOption, ErrorStrategyOption {
    chat_id: string;
    body: {
        userId: string;
        memberType?: string;
        roles: Array<"owner" | "guest">;
        /**
         * Specify the timespan for the conversation history
         */
        visibleHistoryStartDateTime?: string;
        [x: string]: any;
    };
}
declare type AddMemberToTeamsChatResponseOKType = MicrosoftGraphConversationMemberAsResponse;
export interface AddMemberToTeamsChatResponseOK extends AddMemberToTeamsChatResponseOKType {
}
declare type AddMemberToTeamsChatResponseErrorType = ErrorAsResponse;
export interface AddMemberToTeamsChatResponseError extends AddMemberToTeamsChatResponseErrorType {
}
export interface GetTeamsChatMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * key: id
     */
    membership_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "roles" | "visibleHistoryStartDateTime">;
}
declare type GetTeamsChatMemberResponseOKType = MicrosoftGraphConversationMemberAsResponse;
export interface GetTeamsChatMemberResponseOK extends GetTeamsChatMemberResponseOKType {
}
declare type GetTeamsChatMemberResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatMemberResponseError extends GetTeamsChatMemberResponseErrorType {
}
export interface RemoveTeamsChatMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * key: id
     */
    membership_id: string;
}
export declare type RemoveTeamsChatMemberResponseOK = undefined;
declare type RemoveTeamsChatMemberResponseErrorType = ErrorAsResponse;
export interface RemoveTeamsChatMemberResponseError extends RemoveTeamsChatMemberResponseErrorType {
}
export interface GetTeamsChatMessagesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "attachments/content" | "attachments/content desc" | "attachments/contentType" | "attachments/contentType desc" | "attachments/contentUrl" | "attachments/contentUrl desc" | "attachments/id" | "attachments/id desc" | "attachments/name" | "attachments/name desc" | "attachments/thumbnailUrl" | "attachments/thumbnailUrl desc" | "body/content" | "body/content desc" | "body/contentType" | "body/contentType desc" | "channelIdentity/channelId" | "channelIdentity/channelId desc" | "channelIdentity/teamId" | "channelIdentity/teamId desc" | "chatId" | "chatId desc" | "createdDateTime" | "createdDateTime desc" | "deletedDateTime" | "deletedDateTime desc" | "etag" | "etag desc" | "from/application/displayName" | "from/application/displayName desc" | "from/application/id" | "from/application/id desc" | "from/device/displayName" | "from/device/displayName desc" | "from/device/id" | "from/device/id desc" | "from/user/displayName" | "from/user/displayName desc" | "from/user/id" | "from/user/id desc" | "importance" | "importance desc" | "lastEditedDateTime" | "lastEditedDateTime desc" | "lastModifiedDateTime" | "lastModifiedDateTime desc" | "locale" | "locale desc" | "mentions/id" | "mentions/id desc" | "mentions/mentioned/application/displayName" | "mentions/mentioned/application/displayName desc" | "mentions/mentioned/application/id" | "mentions/mentioned/application/id desc" | "mentions/mentioned/device/displayName" | "mentions/mentioned/device/displayName desc" | "mentions/mentioned/device/id" | "mentions/mentioned/device/id desc" | "mentions/mentioned/user/displayName" | "mentions/mentioned/user/displayName desc" | "mentions/mentioned/user/id" | "mentions/mentioned/user/id desc" | "mentions/mentioned/conversation/displayName" | "mentions/mentioned/conversation/displayName desc" | "mentions/mentioned/conversation/id" | "mentions/mentioned/conversation/id desc" | "mentions/mentioned/conversation/conversationIdentityType" | "mentions/mentioned/conversation/conversationIdentityType desc" | "mentions/mentionText" | "mentions/mentionText desc" | "messageType" | "messageType desc" | "policyViolation/dlpAction" | "policyViolation/dlpAction desc" | "policyViolation/justificationText" | "policyViolation/justificationText desc" | "policyViolation/policyTip/complianceUrl" | "policyViolation/policyTip/complianceUrl desc" | "policyViolation/policyTip/generalText" | "policyViolation/policyTip/generalText desc" | "policyViolation/policyTip/matchedConditionDescriptions" | "policyViolation/policyTip/matchedConditionDescriptions desc" | "policyViolation/userAction" | "policyViolation/userAction desc" | "policyViolation/verdictDetails" | "policyViolation/verdictDetails desc" | "reactions/createdDateTime" | "reactions/createdDateTime desc" | "reactions/reactionType" | "reactions/reactionType desc" | "reactions/user/application/displayName" | "reactions/user/application/displayName desc" | "reactions/user/application/id" | "reactions/user/application/id desc" | "reactions/user/device/displayName" | "reactions/user/device/displayName desc" | "reactions/user/device/id" | "reactions/user/device/id desc" | "reactions/user/user/displayName" | "reactions/user/user/displayName desc" | "reactions/user/user/id" | "reactions/user/user/id desc" | "replyToId" | "replyToId desc" | "subject" | "subject desc" | "summary" | "summary desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "attachments" | "body" | "channelIdentity" | "chatId" | "createdDateTime" | "deletedDateTime" | "etag" | "eventDetail" | "from" | "importance" | "lastEditedDateTime" | "lastModifiedDateTime" | "locale" | "mentions" | "messageType" | "policyViolation" | "reactions" | "replyToId" | "subject" | "summary" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "hostedContents" | "replies">;
}
declare type GetTeamsChatMessagesResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphChatMessageAsResponse>;
};
export interface GetTeamsChatMessagesResponseOK extends GetTeamsChatMessagesResponseOKType {
}
declare type GetTeamsChatMessagesResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatMessagesResponseError extends GetTeamsChatMessagesResponseErrorType {
}
export interface SendTeamsChatMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    body: MicrosoftGraphChatMessageCreate;
}
declare type SendTeamsChatMessageResponseOKType = MicrosoftGraphChatMessageAsResponse;
export interface SendTeamsChatMessageResponseOK extends SendTeamsChatMessageResponseOKType {
}
declare type SendTeamsChatMessageResponseErrorType = ErrorAsResponse;
export interface SendTeamsChatMessageResponseError extends SendTeamsChatMessageResponseErrorType {
}
export interface GetTeamsChatMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * key: id
     */
    message_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "attachments" | "body" | "channelIdentity" | "chatId" | "createdDateTime" | "deletedDateTime" | "etag" | "eventDetail" | "from" | "importance" | "lastEditedDateTime" | "lastModifiedDateTime" | "locale" | "mentions" | "messageType" | "policyViolation" | "reactions" | "replyToId" | "subject" | "summary" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "hostedContents" | "replies">;
}
declare type GetTeamsChatMessageResponseOKType = MicrosoftGraphChatMessageAsResponse;
export interface GetTeamsChatMessageResponseOK extends GetTeamsChatMessageResponseOKType {
}
declare type GetTeamsChatMessageResponseErrorType = ErrorAsResponse;
export interface GetTeamsChatMessageResponseError extends GetTeamsChatMessageResponseErrorType {
}
export interface UpdateTeamsChatMessageRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    chat_id: string;
    /**
     * key: id
     */
    message_id: string;
    body: MicrosoftGraphChatMessageUpdate;
}
export declare type UpdateTeamsChatMessageResponseOK = undefined;
declare type UpdateTeamsChatMessageResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsChatMessageResponseError extends UpdateTeamsChatMessageResponseErrorType {
}
export {};
//# sourceMappingURL=chat.d.ts.map