/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { MicrosoftGraphTeamCreate } from "../../definitions/MicrosoftGraphTeamCreate";
import { MicrosoftGraphTeamAsResponse } from "../../definitions/MicrosoftGraphTeamAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { MicrosoftGraphTeamUpdate } from "../../definitions/MicrosoftGraphTeamUpdate";
import { CountAsResponse } from "../../definitions/CountAsResponse";
import { MicrosoftGraphConversationMemberAsResponse } from "../../definitions/MicrosoftGraphConversationMemberAsResponse";
import { MicrosoftGraphAssociatedTeamInfoAsResponse } from "../../definitions/MicrosoftGraphAssociatedTeamInfoAsResponse";
export interface CreateTeamsTeamRequest extends HeadersOption, ErrorStrategyOption {
    body: MicrosoftGraphTeamCreate;
}
declare type CreateTeamsTeamResponseOKType = MicrosoftGraphTeamAsResponse;
export interface CreateTeamsTeamResponseOK extends CreateTeamsTeamResponseOKType {
}
declare type CreateTeamsTeamResponseErrorType = ErrorAsResponse;
export interface CreateTeamsTeamResponseError extends CreateTeamsTeamResponseErrorType {
}
export interface GetTeamsTeamRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "classification" | "createdDateTime" | "description" | "displayName" | "funSettings" | "guestSettings" | "internalId" | "isArchived" | "memberSettings" | "messagingSettings" | "specialization" | "summary" | "tenantId" | "visibility" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "allChannels" | "channels" | "group" | "incomingChannels" | "installedApps" | "members" | "operations" | "photo" | "primaryChannel" | "tags" | "template" | "schedule">;
}
declare type GetTeamsTeamResponseOKType = MicrosoftGraphTeamAsResponse;
export interface GetTeamsTeamResponseOK extends GetTeamsTeamResponseOKType {
}
declare type GetTeamsTeamResponseErrorType = ErrorAsResponse;
export interface GetTeamsTeamResponseError extends GetTeamsTeamResponseErrorType {
}
export interface UpdateTeamsTeamRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    body: MicrosoftGraphTeamUpdate;
}
export declare type UpdateTeamsTeamResponseOK = undefined;
declare type UpdateTeamsTeamResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsTeamResponseError extends UpdateTeamsTeamResponseErrorType {
}
export interface DeleteTeamsTeamRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
}
export declare type DeleteTeamsTeamResponseOK = undefined;
declare type DeleteTeamsTeamResponseErrorType = ErrorAsResponse;
export interface DeleteTeamsTeamResponseError extends DeleteTeamsTeamResponseErrorType {
}
export interface GetTeamsTeamMembersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "displayName" | "displayName desc" | "roles" | "roles desc" | "visibleHistoryStartDateTime" | "visibleHistoryStartDateTime desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "roles" | "visibleHistoryStartDateTime">;
}
declare type GetTeamsTeamMembersResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphConversationMemberAsResponse>;
};
export interface GetTeamsTeamMembersResponseOK extends GetTeamsTeamMembersResponseOKType {
}
declare type GetTeamsTeamMembersResponseErrorType = ErrorAsResponse;
export interface GetTeamsTeamMembersResponseError extends GetTeamsTeamMembersResponseErrorType {
}
export interface AddTeamsTeamMemberRequest extends HeadersOption, ErrorStrategyOption {
    team_id: string;
    body: {
        userId: string;
        memberType?: string;
        roles?: Array<"owner" | "guest">;
        [x: string]: any;
    };
}
declare type AddTeamsTeamMemberResponseOKType = MicrosoftGraphConversationMemberAsResponse;
export interface AddTeamsTeamMemberResponseOK extends AddTeamsTeamMemberResponseOKType {
}
declare type AddTeamsTeamMemberResponseErrorType = ErrorAsResponse;
export interface AddTeamsTeamMemberResponseError extends AddTeamsTeamMemberResponseErrorType {
}
export interface GetTeamsTeamMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    membership_id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "roles" | "visibleHistoryStartDateTime">;
}
declare type GetTeamsTeamMemberResponseOKType = MicrosoftGraphConversationMemberAsResponse;
export interface GetTeamsTeamMemberResponseOK extends GetTeamsTeamMemberResponseOKType {
}
declare type GetTeamsTeamMemberResponseErrorType = ErrorAsResponse;
export interface GetTeamsTeamMemberResponseError extends GetTeamsTeamMemberResponseErrorType {
}
export interface RemoveTeamsTeamMemberRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    team_id: string;
    /**
     * key: id
     */
    membership_id: string;
}
export declare type RemoveTeamsTeamMemberResponseOK = undefined;
declare type RemoveTeamsTeamMemberResponseErrorType = ErrorAsResponse;
export interface RemoveTeamsTeamMemberResponseError extends RemoveTeamsTeamMemberResponseErrorType {
}
export interface UpdateTeamsTeamMemberRequest extends HeadersOption, ErrorStrategyOption {
    team_id: string;
    member_id: string;
    body: {
        memberType?: string;
        roles?: Array<"owner" | "guest">;
        [x: string]: any;
    };
}
export declare type UpdateTeamsTeamMemberResponseOK = undefined;
declare type UpdateTeamsTeamMemberResponseErrorType = ErrorAsResponse;
export interface UpdateTeamsTeamMemberResponseError extends UpdateTeamsTeamMemberResponseErrorType {
}
export interface GetMyTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "classification" | "classification desc" | "createdDateTime" | "createdDateTime desc" | "description" | "description desc" | "displayName" | "displayName desc" | "funSettings/allowCustomMemes" | "funSettings/allowCustomMemes desc" | "funSettings/allowGiphy" | "funSettings/allowGiphy desc" | "funSettings/allowStickersAndMemes" | "funSettings/allowStickersAndMemes desc" | "funSettings/giphyContentRating" | "funSettings/giphyContentRating desc" | "guestSettings/allowCreateUpdateChannels" | "guestSettings/allowCreateUpdateChannels desc" | "guestSettings/allowDeleteChannels" | "guestSettings/allowDeleteChannels desc" | "internalId" | "internalId desc" | "isArchived" | "isArchived desc" | "memberSettings/allowAddRemoveApps" | "memberSettings/allowAddRemoveApps desc" | "memberSettings/allowCreatePrivateChannels" | "memberSettings/allowCreatePrivateChannels desc" | "memberSettings/allowCreateUpdateChannels" | "memberSettings/allowCreateUpdateChannels desc" | "memberSettings/allowCreateUpdateRemoveConnectors" | "memberSettings/allowCreateUpdateRemoveConnectors desc" | "memberSettings/allowCreateUpdateRemoveTabs" | "memberSettings/allowCreateUpdateRemoveTabs desc" | "memberSettings/allowDeleteChannels" | "memberSettings/allowDeleteChannels desc" | "messagingSettings/allowChannelMentions" | "messagingSettings/allowChannelMentions desc" | "messagingSettings/allowOwnerDeleteMessages" | "messagingSettings/allowOwnerDeleteMessages desc" | "messagingSettings/allowTeamMentions" | "messagingSettings/allowTeamMentions desc" | "messagingSettings/allowUserDeleteMessages" | "messagingSettings/allowUserDeleteMessages desc" | "messagingSettings/allowUserEditMessages" | "messagingSettings/allowUserEditMessages desc" | "specialization" | "specialization desc" | "summary/guestsCount" | "summary/guestsCount desc" | "summary/membersCount" | "summary/membersCount desc" | "summary/ownersCount" | "summary/ownersCount desc" | "tenantId" | "tenantId desc" | "visibility" | "visibility desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "classification" | "createdDateTime" | "description" | "displayName" | "funSettings" | "guestSettings" | "internalId" | "isArchived" | "memberSettings" | "messagingSettings" | "specialization" | "summary" | "tenantId" | "visibility" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "allChannels" | "channels" | "group" | "incomingChannels" | "installedApps" | "members" | "operations" | "photo" | "primaryChannel" | "tags" | "template" | "schedule">;
}
declare type GetMyTeamsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphTeamAsResponse>;
};
export interface GetMyTeamsResponseOK extends GetMyTeamsResponseOKType {
}
declare type GetMyTeamsResponseErrorType = ErrorAsResponse;
export interface GetMyTeamsResponseError extends GetMyTeamsResponseErrorType {
}
export interface GetUserTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "classification" | "classification desc" | "createdDateTime" | "createdDateTime desc" | "description" | "description desc" | "displayName" | "displayName desc" | "funSettings/allowCustomMemes" | "funSettings/allowCustomMemes desc" | "funSettings/allowGiphy" | "funSettings/allowGiphy desc" | "funSettings/allowStickersAndMemes" | "funSettings/allowStickersAndMemes desc" | "funSettings/giphyContentRating" | "funSettings/giphyContentRating desc" | "guestSettings/allowCreateUpdateChannels" | "guestSettings/allowCreateUpdateChannels desc" | "guestSettings/allowDeleteChannels" | "guestSettings/allowDeleteChannels desc" | "internalId" | "internalId desc" | "isArchived" | "isArchived desc" | "memberSettings/allowAddRemoveApps" | "memberSettings/allowAddRemoveApps desc" | "memberSettings/allowCreatePrivateChannels" | "memberSettings/allowCreatePrivateChannels desc" | "memberSettings/allowCreateUpdateChannels" | "memberSettings/allowCreateUpdateChannels desc" | "memberSettings/allowCreateUpdateRemoveConnectors" | "memberSettings/allowCreateUpdateRemoveConnectors desc" | "memberSettings/allowCreateUpdateRemoveTabs" | "memberSettings/allowCreateUpdateRemoveTabs desc" | "memberSettings/allowDeleteChannels" | "memberSettings/allowDeleteChannels desc" | "messagingSettings/allowChannelMentions" | "messagingSettings/allowChannelMentions desc" | "messagingSettings/allowOwnerDeleteMessages" | "messagingSettings/allowOwnerDeleteMessages desc" | "messagingSettings/allowTeamMentions" | "messagingSettings/allowTeamMentions desc" | "messagingSettings/allowUserDeleteMessages" | "messagingSettings/allowUserDeleteMessages desc" | "messagingSettings/allowUserEditMessages" | "messagingSettings/allowUserEditMessages desc" | "specialization" | "specialization desc" | "summary/guestsCount" | "summary/guestsCount desc" | "summary/membersCount" | "summary/membersCount desc" | "summary/ownersCount" | "summary/ownersCount desc" | "tenantId" | "tenantId desc" | "visibility" | "visibility desc" | "webUrl" | "webUrl desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "classification" | "createdDateTime" | "description" | "displayName" | "funSettings" | "guestSettings" | "internalId" | "isArchived" | "memberSettings" | "messagingSettings" | "specialization" | "summary" | "tenantId" | "visibility" | "webUrl">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "allChannels" | "channels" | "group" | "incomingChannels" | "installedApps" | "members" | "operations" | "photo" | "primaryChannel" | "tags" | "template" | "schedule">;
}
declare type GetUserTeamsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphTeamAsResponse>;
};
export interface GetUserTeamsResponseOK extends GetUserTeamsResponseOKType {
}
declare type GetUserTeamsResponseErrorType = ErrorAsResponse;
export interface GetUserTeamsResponseError extends GetUserTeamsResponseErrorType {
}
export interface GetUserAssociatedTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "displayName" | "displayName desc" | "tenantId" | "tenantId desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "displayName" | "tenantId">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "team">;
}
declare type GetUserAssociatedTeamsResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphAssociatedTeamInfoAsResponse>;
};
export interface GetUserAssociatedTeamsResponseOK extends GetUserAssociatedTeamsResponseOKType {
}
declare type GetUserAssociatedTeamsResponseErrorType = ErrorAsResponse;
export interface GetUserAssociatedTeamsResponseError extends GetUserAssociatedTeamsResponseErrorType {
}
export {};
//# sourceMappingURL=team.d.ts.map