/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CountAsResponse } from "../definitions/CountAsResponse";
import { MicrosoftGraphUserAsResponse } from "../definitions/MicrosoftGraphUserAsResponse";
import { ErrorAsResponse } from "../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { MicrosoftGraphUserCreate } from "../definitions/MicrosoftGraphUserCreate";
import { MicrosoftGraphUserUpdate } from "../definitions/MicrosoftGraphUserUpdate";
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Show only the first n items, see [Paging - Top](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptiontop)
     */
    $top?: number;
    /**
     * Skip the first n items, see [Paging - Skip](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionskip)
     */
    $skip?: number;
    /**
     * Search items by search phrases, see [Searching](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionsearch)
     */
    $search?: string;
    /**
     * Filter items by property values, see [Filtering](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionfilter)
     */
    $filter?: string;
    /**
     * Include count of items, see [Count](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptioncount)
     */
    $count?: boolean;
    /**
     * Order items by property values, see [Sorting](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionorderby)
     */
    $orderby?: Array<"id" | "id desc" | "deletedDateTime" | "deletedDateTime desc" | "accountEnabled" | "accountEnabled desc" | "ageGroup" | "ageGroup desc" | "assignedLicenses/disabledPlans" | "assignedLicenses/disabledPlans desc" | "assignedLicenses/skuId" | "assignedLicenses/skuId desc" | "assignedPlans/assignedDateTime" | "assignedPlans/assignedDateTime desc" | "assignedPlans/capabilityStatus" | "assignedPlans/capabilityStatus desc" | "assignedPlans/service" | "assignedPlans/service desc" | "assignedPlans/servicePlanId" | "assignedPlans/servicePlanId desc" | "authorizationInfo/certificateUserIds" | "authorizationInfo/certificateUserIds desc" | "businessPhones" | "businessPhones desc" | "city" | "city desc" | "companyName" | "companyName desc" | "consentProvidedForMinor" | "consentProvidedForMinor desc" | "country" | "country desc" | "createdDateTime" | "createdDateTime desc" | "creationType" | "creationType desc" | "department" | "department desc" | "displayName" | "displayName desc" | "employeeHireDate" | "employeeHireDate desc" | "employeeId" | "employeeId desc" | "employeeOrgData/costCenter" | "employeeOrgData/costCenter desc" | "employeeOrgData/division" | "employeeOrgData/division desc" | "employeeType" | "employeeType desc" | "externalUserState" | "externalUserState desc" | "externalUserStateChangeDateTime" | "externalUserStateChangeDateTime desc" | "faxNumber" | "faxNumber desc" | "givenName" | "givenName desc" | "identities/issuer" | "identities/issuer desc" | "identities/issuerAssignedId" | "identities/issuerAssignedId desc" | "identities/signInType" | "identities/signInType desc" | "imAddresses" | "imAddresses desc" | "isResourceAccount" | "isResourceAccount desc" | "jobTitle" | "jobTitle desc" | "lastPasswordChangeDateTime" | "lastPasswordChangeDateTime desc" | "legalAgeGroupClassification" | "legalAgeGroupClassification desc" | "licenseAssignmentStates/assignedByGroup" | "licenseAssignmentStates/assignedByGroup desc" | "licenseAssignmentStates/disabledPlans" | "licenseAssignmentStates/disabledPlans desc" | "licenseAssignmentStates/error" | "licenseAssignmentStates/error desc" | "licenseAssignmentStates/lastUpdatedDateTime" | "licenseAssignmentStates/lastUpdatedDateTime desc" | "licenseAssignmentStates/skuId" | "licenseAssignmentStates/skuId desc" | "licenseAssignmentStates/state" | "licenseAssignmentStates/state desc" | "mail" | "mail desc" | "mailNickname" | "mailNickname desc" | "mobilePhone" | "mobilePhone desc" | "officeLocation" | "officeLocation desc" | "onPremisesDistinguishedName" | "onPremisesDistinguishedName desc" | "onPremisesDomainName" | "onPremisesDomainName desc" | "onPremisesExtensionAttributes/extensionAttribute1" | "onPremisesExtensionAttributes/extensionAttribute1 desc" | "onPremisesExtensionAttributes/extensionAttribute10" | "onPremisesExtensionAttributes/extensionAttribute10 desc" | "onPremisesExtensionAttributes/extensionAttribute11" | "onPremisesExtensionAttributes/extensionAttribute11 desc" | "onPremisesExtensionAttributes/extensionAttribute12" | "onPremisesExtensionAttributes/extensionAttribute12 desc" | "onPremisesExtensionAttributes/extensionAttribute13" | "onPremisesExtensionAttributes/extensionAttribute13 desc" | "onPremisesExtensionAttributes/extensionAttribute14" | "onPremisesExtensionAttributes/extensionAttribute14 desc" | "onPremisesExtensionAttributes/extensionAttribute15" | "onPremisesExtensionAttributes/extensionAttribute15 desc" | "onPremisesExtensionAttributes/extensionAttribute2" | "onPremisesExtensionAttributes/extensionAttribute2 desc" | "onPremisesExtensionAttributes/extensionAttribute3" | "onPremisesExtensionAttributes/extensionAttribute3 desc" | "onPremisesExtensionAttributes/extensionAttribute4" | "onPremisesExtensionAttributes/extensionAttribute4 desc" | "onPremisesExtensionAttributes/extensionAttribute5" | "onPremisesExtensionAttributes/extensionAttribute5 desc" | "onPremisesExtensionAttributes/extensionAttribute6" | "onPremisesExtensionAttributes/extensionAttribute6 desc" | "onPremisesExtensionAttributes/extensionAttribute7" | "onPremisesExtensionAttributes/extensionAttribute7 desc" | "onPremisesExtensionAttributes/extensionAttribute8" | "onPremisesExtensionAttributes/extensionAttribute8 desc" | "onPremisesExtensionAttributes/extensionAttribute9" | "onPremisesExtensionAttributes/extensionAttribute9 desc" | "onPremisesImmutableId" | "onPremisesImmutableId desc" | "onPremisesLastSyncDateTime" | "onPremisesLastSyncDateTime desc" | "onPremisesProvisioningErrors/category" | "onPremisesProvisioningErrors/category desc" | "onPremisesProvisioningErrors/occurredDateTime" | "onPremisesProvisioningErrors/occurredDateTime desc" | "onPremisesProvisioningErrors/propertyCausingError" | "onPremisesProvisioningErrors/propertyCausingError desc" | "onPremisesProvisioningErrors/value" | "onPremisesProvisioningErrors/value desc" | "onPremisesSamAccountName" | "onPremisesSamAccountName desc" | "onPremisesSecurityIdentifier" | "onPremisesSecurityIdentifier desc" | "onPremisesSyncEnabled" | "onPremisesSyncEnabled desc" | "onPremisesUserPrincipalName" | "onPremisesUserPrincipalName desc" | "otherMails" | "otherMails desc" | "passwordPolicies" | "passwordPolicies desc" | "passwordProfile/forceChangePasswordNextSignIn" | "passwordProfile/forceChangePasswordNextSignIn desc" | "passwordProfile/forceChangePasswordNextSignInWithMfa" | "passwordProfile/forceChangePasswordNextSignInWithMfa desc" | "passwordProfile/password" | "passwordProfile/password desc" | "postalCode" | "postalCode desc" | "preferredDataLocation" | "preferredDataLocation desc" | "preferredLanguage" | "preferredLanguage desc" | "provisionedPlans/capabilityStatus" | "provisionedPlans/capabilityStatus desc" | "provisionedPlans/provisioningStatus" | "provisionedPlans/provisioningStatus desc" | "provisionedPlans/service" | "provisionedPlans/service desc" | "proxyAddresses" | "proxyAddresses desc" | "securityIdentifier" | "securityIdentifier desc" | "showInAddressList" | "showInAddressList desc" | "signInSessionsValidFromDateTime" | "signInSessionsValidFromDateTime desc" | "state" | "state desc" | "streetAddress" | "streetAddress desc" | "surname" | "surname desc" | "usageLocation" | "usageLocation desc" | "userPrincipalName" | "userPrincipalName desc" | "userType" | "userType desc" | "mailboxSettings/archiveFolder" | "mailboxSettings/archiveFolder desc" | "mailboxSettings/automaticRepliesSetting/externalAudience" | "mailboxSettings/automaticRepliesSetting/externalAudience desc" | "mailboxSettings/automaticRepliesSetting/externalReplyMessage" | "mailboxSettings/automaticRepliesSetting/externalReplyMessage desc" | "mailboxSettings/automaticRepliesSetting/internalReplyMessage" | "mailboxSettings/automaticRepliesSetting/internalReplyMessage desc" | "mailboxSettings/automaticRepliesSetting/scheduledEndDateTime/dateTime" | "mailboxSettings/automaticRepliesSetting/scheduledEndDateTime/dateTime desc" | "mailboxSettings/automaticRepliesSetting/scheduledEndDateTime/timeZone" | "mailboxSettings/automaticRepliesSetting/scheduledEndDateTime/timeZone desc" | "mailboxSettings/automaticRepliesSetting/scheduledStartDateTime/dateTime" | "mailboxSettings/automaticRepliesSetting/scheduledStartDateTime/dateTime desc" | "mailboxSettings/automaticRepliesSetting/scheduledStartDateTime/timeZone" | "mailboxSettings/automaticRepliesSetting/scheduledStartDateTime/timeZone desc" | "mailboxSettings/automaticRepliesSetting/status" | "mailboxSettings/automaticRepliesSetting/status desc" | "mailboxSettings/dateFormat" | "mailboxSettings/dateFormat desc" | "mailboxSettings/delegateMeetingMessageDeliveryOptions" | "mailboxSettings/delegateMeetingMessageDeliveryOptions desc" | "mailboxSettings/language/displayName" | "mailboxSettings/language/displayName desc" | "mailboxSettings/language/locale" | "mailboxSettings/language/locale desc" | "mailboxSettings/timeFormat" | "mailboxSettings/timeFormat desc" | "mailboxSettings/timeZone" | "mailboxSettings/timeZone desc" | "mailboxSettings/userPurpose" | "mailboxSettings/userPurpose desc" | "mailboxSettings/workingHours/daysOfWeek" | "mailboxSettings/workingHours/daysOfWeek desc" | "mailboxSettings/workingHours/endTime" | "mailboxSettings/workingHours/endTime desc" | "mailboxSettings/workingHours/startTime" | "mailboxSettings/workingHours/startTime desc" | "mailboxSettings/workingHours/timeZone/name" | "mailboxSettings/workingHours/timeZone/name desc" | "deviceEnrollmentLimit" | "deviceEnrollmentLimit desc" | "aboutMe" | "aboutMe desc" | "birthday" | "birthday desc" | "hireDate" | "hireDate desc" | "interests" | "interests desc" | "mySite" | "mySite desc" | "pastProjects" | "pastProjects desc" | "preferredName" | "preferredName desc" | "responsibilities" | "responsibilities desc" | "schools" | "schools desc" | "skills" | "skills desc">;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "deletedDateTime" | "accountEnabled" | "ageGroup" | "assignedLicenses" | "assignedPlans" | "authorizationInfo" | "businessPhones" | "city" | "companyName" | "consentProvidedForMinor" | "country" | "createdDateTime" | "creationType" | "department" | "displayName" | "employeeHireDate" | "employeeId" | "employeeOrgData" | "employeeType" | "externalUserState" | "externalUserStateChangeDateTime" | "faxNumber" | "givenName" | "identities" | "imAddresses" | "isResourceAccount" | "jobTitle" | "lastPasswordChangeDateTime" | "legalAgeGroupClassification" | "licenseAssignmentStates" | "mail" | "mailNickname" | "mobilePhone" | "officeLocation" | "onPremisesDistinguishedName" | "onPremisesDomainName" | "onPremisesExtensionAttributes" | "onPremisesImmutableId" | "onPremisesLastSyncDateTime" | "onPremisesProvisioningErrors" | "onPremisesSamAccountName" | "onPremisesSecurityIdentifier" | "onPremisesSyncEnabled" | "onPremisesUserPrincipalName" | "otherMails" | "passwordPolicies" | "passwordProfile" | "postalCode" | "preferredDataLocation" | "preferredLanguage" | "provisionedPlans" | "proxyAddresses" | "securityIdentifier" | "showInAddressList" | "signInSessionsValidFromDateTime" | "state" | "streetAddress" | "surname" | "usageLocation" | "userPrincipalName" | "userType" | "mailboxSettings" | "deviceEnrollmentLimit" | "aboutMe" | "birthday" | "hireDate" | "interests" | "mySite" | "pastProjects" | "preferredName" | "responsibilities" | "schools" | "skills">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "appRoleAssignments" | "createdObjects" | "directReports" | "licenseDetails" | "manager" | "memberOf" | "oauth2PermissionGrants" | "ownedDevices" | "ownedObjects" | "registeredDevices" | "scopedRoleMemberOf" | "transitiveMemberOf" | "calendar" | "calendarGroups" | "calendars" | "calendarView" | "contactFolders" | "contacts" | "events" | "inferenceClassification" | "mailFolders" | "messages" | "outlook" | "people" | "drive" | "drives" | "followedSites" | "extensions" | "agreementAcceptances" | "managedDevices" | "managedAppRegistrations" | "deviceManagementTroubleshootingEvents" | "planner" | "insights" | "settings" | "onenote" | "photo" | "photos" | "activities" | "onlineMeetings" | "presence" | "authentication" | "chats" | "joinedTeams" | "teamwork" | "todo">;
}
declare type GetUsersResponseOKType = {
    "@odata.count"?: CountAsResponse;
    value?: Array<MicrosoftGraphUserAsResponse>;
};
export interface GetUsersResponseOK extends GetUsersResponseOKType {
}
declare type GetUsersResponseErrorType = ErrorAsResponse;
export interface GetUsersResponseError extends GetUsersResponseErrorType {
}
export interface CreateUserRequest extends HeadersOption, ErrorStrategyOption {
    body: MicrosoftGraphUserCreate;
}
declare type CreateUserResponseOKType = MicrosoftGraphUserAsResponse;
export interface CreateUserResponseOK extends CreateUserResponseOKType {
}
declare type CreateUserResponseErrorType = ErrorAsResponse;
export interface CreateUserResponseError extends CreateUserResponseErrorType {
}
export interface GetUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "deletedDateTime" | "accountEnabled" | "ageGroup" | "assignedLicenses" | "assignedPlans" | "authorizationInfo" | "businessPhones" | "city" | "companyName" | "consentProvidedForMinor" | "country" | "createdDateTime" | "creationType" | "department" | "displayName" | "employeeHireDate" | "employeeId" | "employeeOrgData" | "employeeType" | "externalUserState" | "externalUserStateChangeDateTime" | "faxNumber" | "givenName" | "identities" | "imAddresses" | "isResourceAccount" | "jobTitle" | "lastPasswordChangeDateTime" | "legalAgeGroupClassification" | "licenseAssignmentStates" | "mail" | "mailNickname" | "mobilePhone" | "officeLocation" | "onPremisesDistinguishedName" | "onPremisesDomainName" | "onPremisesExtensionAttributes" | "onPremisesImmutableId" | "onPremisesLastSyncDateTime" | "onPremisesProvisioningErrors" | "onPremisesSamAccountName" | "onPremisesSecurityIdentifier" | "onPremisesSyncEnabled" | "onPremisesUserPrincipalName" | "otherMails" | "passwordPolicies" | "passwordProfile" | "postalCode" | "preferredDataLocation" | "preferredLanguage" | "provisionedPlans" | "proxyAddresses" | "securityIdentifier" | "showInAddressList" | "signInSessionsValidFromDateTime" | "state" | "streetAddress" | "surname" | "usageLocation" | "userPrincipalName" | "userType" | "mailboxSettings" | "deviceEnrollmentLimit" | "aboutMe" | "birthday" | "hireDate" | "interests" | "mySite" | "pastProjects" | "preferredName" | "responsibilities" | "schools" | "skills">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "appRoleAssignments" | "createdObjects" | "directReports" | "licenseDetails" | "manager" | "memberOf" | "oauth2PermissionGrants" | "ownedDevices" | "ownedObjects" | "registeredDevices" | "scopedRoleMemberOf" | "transitiveMemberOf" | "calendar" | "calendarGroups" | "calendars" | "calendarView" | "contactFolders" | "contacts" | "events" | "inferenceClassification" | "mailFolders" | "messages" | "outlook" | "people" | "drive" | "drives" | "followedSites" | "extensions" | "agreementAcceptances" | "managedDevices" | "managedAppRegistrations" | "deviceManagementTroubleshootingEvents" | "planner" | "insights" | "settings" | "onenote" | "photo" | "photos" | "activities" | "onlineMeetings" | "presence" | "authentication" | "chats" | "joinedTeams" | "teamwork" | "todo">;
}
declare type GetUserResponseOKType = MicrosoftGraphUserAsResponse;
export interface GetUserResponseOK extends GetUserResponseOKType {
}
declare type GetUserResponseErrorType = ErrorAsResponse;
export interface GetUserResponseError extends GetUserResponseErrorType {
}
export interface UpdateUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
    body: MicrosoftGraphUserUpdate;
}
export declare type UpdateUserResponseOK = undefined;
declare type UpdateUserResponseErrorType = ErrorAsResponse;
export interface UpdateUserResponseError extends UpdateUserResponseErrorType {
}
export interface DeleteUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * key: id
     */
    id: string;
}
export declare type DeleteUserResponseOK = undefined;
declare type DeleteUserResponseErrorType = ErrorAsResponse;
export interface DeleteUserResponseError extends DeleteUserResponseErrorType {
}
export interface GetMyUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Select properties to be returned, see [Select](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionselect)
     */
    $select?: Array<"id" | "deletedDateTime" | "accountEnabled" | "ageGroup" | "assignedLicenses" | "assignedPlans" | "authorizationInfo" | "businessPhones" | "city" | "companyName" | "consentProvidedForMinor" | "country" | "createdDateTime" | "creationType" | "department" | "displayName" | "employeeHireDate" | "employeeId" | "employeeOrgData" | "employeeType" | "externalUserState" | "externalUserStateChangeDateTime" | "faxNumber" | "givenName" | "identities" | "imAddresses" | "isResourceAccount" | "jobTitle" | "lastPasswordChangeDateTime" | "legalAgeGroupClassification" | "licenseAssignmentStates" | "mail" | "mailNickname" | "mobilePhone" | "officeLocation" | "onPremisesDistinguishedName" | "onPremisesDomainName" | "onPremisesExtensionAttributes" | "onPremisesImmutableId" | "onPremisesLastSyncDateTime" | "onPremisesProvisioningErrors" | "onPremisesSamAccountName" | "onPremisesSecurityIdentifier" | "onPremisesSyncEnabled" | "onPremisesUserPrincipalName" | "otherMails" | "passwordPolicies" | "passwordProfile" | "postalCode" | "preferredDataLocation" | "preferredLanguage" | "provisionedPlans" | "proxyAddresses" | "securityIdentifier" | "showInAddressList" | "signInSessionsValidFromDateTime" | "state" | "streetAddress" | "surname" | "usageLocation" | "userPrincipalName" | "userType" | "mailboxSettings" | "deviceEnrollmentLimit" | "aboutMe" | "birthday" | "hireDate" | "interests" | "mySite" | "pastProjects" | "preferredName" | "responsibilities" | "schools" | "skills">;
    /**
     * Expand related entities, see [Expand](http://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html#sec_SystemQueryOptionexpand)
     */
    $expand?: Array<"*" | "appRoleAssignments" | "createdObjects" | "directReports" | "licenseDetails" | "manager" | "memberOf" | "oauth2PermissionGrants" | "ownedDevices" | "ownedObjects" | "registeredDevices" | "scopedRoleMemberOf" | "transitiveMemberOf" | "calendar" | "calendarGroups" | "calendars" | "calendarView" | "contactFolders" | "contacts" | "events" | "inferenceClassification" | "mailFolders" | "messages" | "outlook" | "people" | "drive" | "drives" | "followedSites" | "extensions" | "agreementAcceptances" | "managedDevices" | "managedAppRegistrations" | "deviceManagementTroubleshootingEvents" | "planner" | "insights" | "settings" | "onenote" | "photo" | "photos" | "activities" | "onlineMeetings" | "presence" | "authentication" | "chats" | "joinedTeams" | "teamwork" | "todo">;
}
declare type GetMyUserResponseOKType = MicrosoftGraphUserAsResponse;
export interface GetMyUserResponseOK extends GetMyUserResponseOKType {
}
declare type GetMyUserResponseErrorType = ErrorAsResponse;
export interface GetMyUserResponseError extends GetMyUserResponseErrorType {
}
export {};
//# sourceMappingURL=users.d.ts.map